// Copyright (c) 2015, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

(function() {
  'use strict';

  let dart_sdk = dart_library.import('dart_sdk');
  dart_sdk._isolate_helper.startRootIsolate(function() {}, []);
  let async_helper = dart_library.import('async_helper').async_helper;
  let unittest = dart_library.import('unittest');
  let html_config = unittest.html_config;
  // Test attributes are a list of strings, or a string for a single
  // attribute. Valid attributes are:
  //
  //   'notyetstrong' - test is not yet strong mode safe
  //   'skip' - don't run the test
  //   'fail' - test fails
  //   'timeout' - test times out
  //   'slow' - use 5s timeout instead of default 2s.
  //   'helper'  - not a test, used by other tests.
  //   'unittest' - run separately as a unittest test.
  //
  // Common combinations:
  const notyetstrong = 'notyetstrong';
  const fail = 'fail';
  const skip_fail = ['skip', 'fail'];
  const skip_timeout = ['skip', 'timeout'];

  // The number of expected unittest errors should be zero but unfortunately
  // there are a lot of broken html unittests.
  let num_expected_unittest_fails = 3;
  let num_expected_unittest_errors = 2;

  // TODO(jmesserly): separate StrongModeError from other errors.
  let all_status = {
    'language': {
      'assert_with_type_test_or_cast_test': skip_fail,
      'assertion_test': skip_fail,
      'async_await_test_none_multi': 'unittest',
      'async_star_await_pauses_test': skip_fail,

      // TODO(jmesserly): figure out why this test is hanging.
      'async_star_cancel_and_throw_in_finally_test': skip_timeout,

      'async_star_cancel_while_paused_test': skip_fail,
      'async_star_regression_fisk_test': skip_fail,

      // TODO(vsm): Re-enable.
      // See https://github.com/dart-lang/dev_compiler/issues/456
      'async_star_test_none_multi': ['unittest', 'skip', 'fail'],
      'async_star_test_01_multi': ['unittest', 'skip', 'fail'],
      'async_star_test_02_multi': ['unittest', 'skip', 'fail'],
      'async_star_test_03_multi': ['unittest', 'skip', 'fail'],
      'async_star_test_04_multi': ['unittest', 'skip', 'fail'],
      'async_star_test_05_multi': ['unittest', 'skip', 'fail'],

      'async_switch_test': skip_fail,
      'asyncstar_throw_in_catch_test': skip_fail,
      'await_future_test': skip_fail,
      'bit_operations_test_none_multi': skip_fail,  // DDC/dart2js canonicalize bitop results to unsigned
      'bool_test': skip_fail,
      'bound_closure_equality_test': skip_fail,
      'branch_canonicalization_test': skip_fail,  // JS bit operations truncate to 32 bits.
      'call_closurization_test': fail, // Functions do not expose a "call" method.
      'call_function_apply_test': fail, // Function.apply not really implemented.
      'call_test': fail, // Functions do not expose a "call" method.
      'call_through_null_getter_test': fail, // null errors are not converted to NoSuchMethodErrors.
      'call_with_no_such_method_test': fail, // Function.apply not really implemented.
      'canonical_const2_test': skip_fail,
      'canonical_const_test': skip_fail,
      'cascade_precedence_test': skip_fail,
      'cast_test_01_multi': skip_fail,
      'cast_test_02_multi': skip_fail,
      'cast_test_03_multi': skip_fail,
      'cast_test_07_multi': skip_fail,
      'cast_test_10_multi': skip_fail,
      'cast_test_12_multi': skip_fail,
      'cast_test_13_multi': skip_fail,
      'cast_test_14_multi': skip_fail,
      'cast_test_15_multi': skip_fail,
      'cha_deopt1_test': skip_fail,
      'cha_deopt2_test': skip_fail,
      'cha_deopt3_test': skip_fail,

      // interpolation does not call Dart's toString:
      // https://github.com/dart-lang/dev_compiler/issues/470
      'class_syntax2_test': skip_fail,
      'classes_static_method_clash_test': skip_fail,
      'closure_call_wrong_argument_count_negative_test': skip_fail,
      'closure_in_constructor_test': skip_fail,
      'closure_with_super_field_test': skip_fail,
      'closures_initializer_test': skip_fail,
      'code_after_try_is_executed_test_01_multi': skip_fail,
      'compile_time_constant10_test_none_multi': skip_fail,
      'compile_time_constant_a_test': skip_fail,
      'compile_time_constant_b_test': skip_fail,
      'compile_time_constant_d_test': skip_fail,
      'compile_time_constant_i_test': skip_fail,
      'compile_time_constant_k_test_none_multi': skip_fail,
      'compile_time_constant_o_test_none_multi': skip_fail,
      'const_constructor3_test_03_multi': skip_fail,
      'const_escape_frog_test': skip_fail,
      'const_evaluation_test_01_multi': skip_fail,
      'const_map4_test': skip_fail,
      'const_switch_test_02_multi': skip_fail,
      'const_switch_test_04_multi': skip_fail,
      'constructor11_test': skip_fail,
      'constructor12_test': skip_fail,
      'ct_const_test': skip_fail,
      'cyclic_type2_test': skip_fail,
      'cyclic_type_test_00_multi': skip_fail,
      'cyclic_type_test_01_multi': skip_fail,
      'cyclic_type_test_02_multi': skip_fail,
      'cyclic_type_test_03_multi': skip_fail,
      'cyclic_type_test_04_multi': skip_fail,
      'cyclic_type_variable_test_none_multi': skip_fail,
      'deferred_call_empty_before_load_test': skip_fail,
      'deferred_closurize_load_library_test': skip_fail,
      'deferred_constant_list_test': skip_fail,
      'deferred_function_type_test': skip_fail,
      'deferred_inlined_test': skip_fail,
      'deferred_load_inval_code_test': skip_fail,
      'deferred_mixin_test': skip_fail,
      'deferred_no_such_method_test': skip_fail, // deferred libs not implemented
      'deferred_not_loaded_check_test': skip_fail,
      'deferred_only_constant_test': skip_fail,
      'deferred_optimized_test': skip_fail,
      'deferred_redirecting_factory_test': skip_fail,
      'deferred_regression_22995_test': skip_fail,
      'deferred_shadow_load_library_test': skip_fail,
      'deferred_shared_and_unshared_classes_test': skip_fail,
      'deferred_static_seperate_test': skip_fail,
      'double_int_to_string_test': skip_fail,
      'double_to_string_test': skip_fail,
      'dynamic_test': skip_fail,
      'enum_mirror_test': skip_fail,
      'exception_test': fail,
      'execute_finally6_test': skip_fail,
      'expect_test': skip_fail,
      'extends_test_lib': skip_fail,
      'external_test_10_multi': skip_fail,
      'external_test_13_multi': skip_fail,
      'external_test_20_multi': skip_fail,
      'f_bounded_quantification3_test': skip_fail,
      'factory_type_parameter_test': skip_fail,
      'fast_method_extraction_test': skip_fail,
      'field_increment_bailout_test': fail,
      'field_optimization3_test': skip_fail,
      'final_syntax_test_08_multi': skip_fail,
      'first_class_types_test': skip_fail,
      'for_in2_test': skip_fail,
      'for_variable_capture_test': skip_fail,
      'function_subtype0_test': skip_fail,
      'function_subtype1_test': skip_fail,
      'function_subtype2_test': skip_fail,
      'function_subtype3_test': skip_fail,
      'function_subtype_bound_closure0_test': skip_fail,
      'function_subtype_bound_closure1_test': skip_fail,
      'function_subtype_bound_closure2_test': skip_fail,
      'function_subtype_bound_closure3_test': skip_fail,
      'function_subtype_bound_closure4_test': skip_fail,
      'function_subtype_bound_closure5_test': skip_fail,
      'function_subtype_bound_closure5a_test': skip_fail,
      'function_subtype_bound_closure6_test': skip_fail,
      'function_subtype_call0_test': fail, // Strong mode "is" rejects some type tests.
      'function_subtype_call1_test': fail,
      'function_subtype_call2_test': fail,
      'function_subtype_cast0_test': fail,
      'function_subtype_cast1_test': fail,
      'function_subtype_cast2_test': fail,
      'function_subtype_cast3_test': fail,
      'function_subtype_factory0_test': skip_fail,
      'function_subtype_inline0_test': skip_fail,
      'function_subtype_local0_test': skip_fail,
      'function_subtype_local1_test': skip_fail,
      'function_subtype_local2_test': skip_fail,
      'function_subtype_local3_test': skip_fail,
      'function_subtype_local4_test': skip_fail,
      'function_subtype_local5_test': skip_fail,
      'function_subtype_named1_test': skip_fail,
      'function_subtype_named2_test': skip_fail,
      'function_subtype_not0_test': skip_fail,
      'function_subtype_not1_test': skip_fail,
      'function_subtype_not2_test': skip_fail,
      'function_subtype_not3_test': skip_fail,
      'function_subtype_optional1_test': skip_fail,
      'function_subtype_optional2_test': skip_fail,
      'function_subtype_top_level0_test': skip_fail,
      'function_subtype_top_level1_test': skip_fail,
      'function_subtype_typearg0_test': skip_fail,
      'function_subtype_typearg2_test': skip_fail,
      'function_subtype_typearg4_test': skip_fail,
      'function_type_alias2_test': skip_fail,
      'function_type_alias3_test': skip_fail,
      'function_type_alias4_test': skip_fail,
      'function_type_alias6_test_none_multi': skip_fail,
      'function_type_alias_test': skip_fail,
      'gc_test': skip_fail,
      'generic_field_mixin2_test': skip_fail,
      'generic_field_mixin3_test': skip_fail,
      'generic_field_mixin4_test': skip_fail,
      'generic_field_mixin5_test': skip_fail,
      'generic_field_mixin_test': skip_fail,
      'generic_instanceof2_test': skip_fail,
      'generic_is_check_test': skip_fail,
      'getter_closure_execution_order_test': skip_fail,
      'getter_override2_test_00_multi': skip_fail,
      'getters_setters_test': skip_fail,
      'hash_code_mangling_test': skip_fail,
      'identical_closure2_test': skip_fail,
      'infinite_switch_label_test': skip_fail,
      'infinity_test': skip_fail,
      'instance_creation_in_function_annotation_test': skip_fail,
      'instanceof2_test': fail,
      'instanceof4_test_01_multi': fail,
      'instanceof4_test_none_multi': fail,
      'instanceof_optimized_test': skip_fail,
      'integer_division_by_zero_test': fail,
      'is_nan_test': fail,
      'issue10747_test': skip_fail,
      'issue13179_test': skip_fail,
      'issue21079_test': skip_fail,
      'issue21957_test': skip_fail,
      'issue_1751477_test': skip_fail,
      'issue_22780_test_01_multi': skip_fail,
      'issue_23914_test': skip_fail,
      'js_properties_test': skip_fail,
      'lazy_static3_test': skip_fail,
      'least_upper_bound_expansive_test_none_multi': skip_fail,
      'left_shift_test': skip_fail,
      'list_is_test': skip_fail,
      'list_literal3_test': skip_fail,
      'many_generic_instanceof_test': skip_fail,
      'map_literal10_test': skip_fail,
      'map_literal7_test': skip_fail,
      'memory_swap_test': skip_fail,
      'method_invocation_test': skip_fail,
      'mint_arithmetic_test': skip_fail,
      'mixin_forwarding_constructor3_test': skip_fail,
      'mixin_generic_test': skip_fail,
      'mixin_implements_test': skip_fail,
      'mixin_issue10216_2_test': skip_fail,
      'mixin_mixin2_test': skip_fail,
      'mixin_mixin3_test': skip_fail,
      'mixin_mixin4_test': skip_fail,
      'mixin_mixin5_test': skip_fail,
      'mixin_mixin6_test': skip_fail,
      'mixin_mixin7_test': skip_fail,
      'mixin_mixin_bound2_test': skip_fail,
      'mixin_mixin_bound_test': skip_fail,
      'mixin_mixin_test': skip_fail,
      'mixin_regress_13688_test': skip_fail,
      'mixin_type_parameter1_test': skip_fail,
      'mixin_type_parameter2_test': skip_fail,
      'mixin_type_parameter3_test': skip_fail,
      'modulo_test': fail,
      'named_parameter_clash_test': skip_fail,
      'nan_identical_test': skip_fail,
      'nested_switch_label_test': skip_fail,
      'no_such_method_empty_selector_test': fail,
      'number_identifier_test_05_multi': skip_fail,
      'number_identity2_test': skip_fail,
      'numbers_test': skip_fail,
      'optimized_hoisting_checked_mode_assert_test': skip_fail,
      'redirecting_factory_reflection_test': skip_fail,
      'regress_13462_0_test': skip_fail,
      'regress_13462_1_test': skip_fail,
      'regress_14105_test': skip_fail,
      'regress_16640_test': skip_fail,
      'regress_18535_test': skip_fail,
      'regress_21795_test': skip_fail,
      'regress_22443_test': skip_fail,
      'regress_22666_test': skip_fail,
      'setter_no_getter_test_01_multi': skip_fail,
      'stack_overflow_stacktrace_test': skip_fail,
      'stack_overflow_test': skip_fail,
      'stack_trace_test': skip_fail,
      'stacktrace_rethrow_nonerror_test': skip_fail, // mismatch from Karma's file hash
      'stacktrace_rethrow_error_test_none_multi': skip_fail,
      'stacktrace_rethrow_error_test_withtraceparameter_multi': skip_fail,
      'stacktrace_test': skip_fail,
      'string_interpolate_null_test': skip_fail,
      'super_field_2_test': skip_fail,
      'super_field_test': skip_fail,
      'super_operator_index3_test': skip_fail,
      'super_operator_index4_test': skip_fail,
      'switch_label2_test': skip_fail,
      'switch_label_test': skip_fail,
      'switch_try_catch_test': skip_fail,
      'sync_generator1_test_none_multi': skip_fail,
      'throwing_lazy_variable_test': skip_fail,
      'top_level_non_prefixed_library_test': skip_fail,
      'truncdiv_test': fail,  // did not throw
      'type_variable_nested_test': skip_fail,  // unsound is-check
      'type_variable_typedef_test': skip_fail,  // unsound is-check

      'bit_operations_test_01_multi': skip_fail,
      'bit_operations_test_02_multi': skip_fail,
      'bit_operations_test_03_multi': skip_fail,
      'bit_operations_test_04_multi': skip_fail,
      'bool_condition_check_test_01_multi': skip_fail,
      'deferred_constraints_constants_test_none_multi': skip_fail,
      'deferred_constraints_constants_test_reference_after_load_multi': skip_fail,
      'deferred_constraints_type_annotation_test_new_generic1_multi': skip_fail,
      'deferred_constraints_type_annotation_test_new_multi': skip_fail,
      'deferred_constraints_type_annotation_test_none_multi': skip_fail,
      'deferred_constraints_type_annotation_test_static_method_multi': skip_fail,
      'deferred_constraints_type_annotation_test_type_annotation_non_deferred_multi': skip_fail,
      'deferred_load_constants_test_none_multi': skip_fail,
      'deferred_load_library_wrong_args_test_01_multi': skip_fail,
      'deferred_load_library_wrong_args_test_none_multi': skip_fail,
      'external_test_21_multi': skip_fail,
      'external_test_24_multi': skip_fail,
      'main_not_a_function_test_01_multi': skip_fail,
      'multiline_newline_test_04_multi': skip_fail,
      'multiline_newline_test_05_multi': skip_fail,
      'multiline_newline_test_06_multi': skip_fail,
      'multiline_newline_test_none_multi': skip_fail,
      'no_main_test_01_multi': skip_fail,

      // https://github.com/dart-lang/sdk/issues/26123
      'bad_raw_string_negative_test': skip_fail,

      // https://github.com/dart-lang/sdk/issues/26124
      'prefix10_negative_test': skip_fail,

      'library_prefixes_test1': 'helper',
      'library_prefixes_test2': 'helper',
      'top_level_prefixed_library_test': 'helper',

      'abstract_exact_selector_test_01_multi': notyetstrong,
      'abstract_factory_constructor_test_00_multi': notyetstrong,
      'abstract_getter_test_01_multi': notyetstrong,
      'abstract_runtime_error_test_01_multi': notyetstrong,
      'abstract_runtime_error_test_02_multi': notyetstrong,
      'abstract_runtime_error_test_03_multi': notyetstrong,
      'abstract_syntax_test_00_multi': notyetstrong,
      'abstract_syntax_test_01_multi': notyetstrong,
      'application_test': notyetstrong,
      'argument_definition_test_01_multi': notyetstrong,
      'arithmetic_test': notyetstrong,
      'assign_static_type_test_01_multi': notyetstrong,
      'assign_static_type_test_02_multi': notyetstrong,
      'assign_static_type_test_03_multi': notyetstrong,
      'assign_static_type_test_04_multi': notyetstrong,
      'assign_static_type_test_05_multi': notyetstrong,
      'assign_static_type_test_06_multi': notyetstrong,
      'assign_to_type_test_01_multi': notyetstrong,
      'assign_to_type_test_02_multi': notyetstrong,
      'assign_to_type_test_03_multi': notyetstrong,
      'assign_to_type_test_04_multi': notyetstrong,
      'assign_top_method_test_01_multi': notyetstrong,
      'assignable_expression_test_01_multi': notyetstrong,
      'assignable_expression_test_02_multi': notyetstrong,
      'assignable_expression_test_03_multi': notyetstrong,
      'assignable_expression_test_11_multi': notyetstrong,
      'assignable_expression_test_12_multi': notyetstrong,
      'assignable_expression_test_13_multi': notyetstrong,
      'assignable_expression_test_21_multi': notyetstrong,
      'assignable_expression_test_22_multi': notyetstrong,
      'assignable_expression_test_23_multi': notyetstrong,
      'assignable_expression_test_31_multi': notyetstrong,
      'assignable_expression_test_32_multi': notyetstrong,
      'assignable_expression_test_33_multi': notyetstrong,
      'assignable_expression_test_41_multi': notyetstrong,
      'assignable_expression_test_42_multi': notyetstrong,
      'assignable_expression_test_43_multi': notyetstrong,
      'assignable_expression_test_50_multi': notyetstrong,
      'assignable_expression_test_none_multi': notyetstrong,
      'async_await_syntax_test_a01b_multi': notyetstrong,
      'async_await_syntax_test_a01c_multi': notyetstrong,
      'async_await_syntax_test_a01d_multi': notyetstrong,
      'async_await_syntax_test_a04b_multi': notyetstrong,
      'async_await_syntax_test_a05d_multi': notyetstrong,
      'async_await_syntax_test_a05f_multi': notyetstrong,
      'async_await_syntax_test_a05g_multi': notyetstrong,
      'async_await_syntax_test_a05h_multi': notyetstrong,
      'async_await_syntax_test_a06b_multi': notyetstrong,
      'async_await_syntax_test_a07b_multi': notyetstrong,
      'async_await_syntax_test_a08b_multi': notyetstrong,
      'async_await_syntax_test_a10a_multi': notyetstrong,
      'async_await_syntax_test_a11a_multi': notyetstrong,
      'async_await_syntax_test_a12b_multi': notyetstrong,
      'async_await_syntax_test_a12d_multi': notyetstrong,
      'async_await_syntax_test_a12e_multi': notyetstrong,
      'async_await_syntax_test_a12f_multi': notyetstrong,
      'async_await_syntax_test_a13b_multi': notyetstrong,
      'async_await_syntax_test_a13d_multi': notyetstrong,
      'async_await_syntax_test_a14b_multi': notyetstrong,
      'async_await_syntax_test_a14d_multi': notyetstrong,
      'async_await_syntax_test_a15b_multi': notyetstrong,
      'async_await_syntax_test_a15d_multi': notyetstrong,
      'async_await_syntax_test_b00a_multi': notyetstrong,
      'async_await_syntax_test_b00b_multi': notyetstrong,
      'async_await_syntax_test_b00c_multi': notyetstrong,
      'async_await_syntax_test_b00d_multi': notyetstrong,
      'async_await_syntax_test_b01b_multi': notyetstrong,
      'async_await_syntax_test_b01c_multi': notyetstrong,
      'async_await_syntax_test_b04b_multi': notyetstrong,
      'async_await_syntax_test_b06b_multi': notyetstrong,
      'async_await_syntax_test_b10a_multi': notyetstrong,
      'async_await_syntax_test_b10b_multi': notyetstrong,
      'async_await_syntax_test_b11a_multi': notyetstrong,
      'async_await_syntax_test_b12b_multi': notyetstrong,
      'async_await_syntax_test_b12d_multi': notyetstrong,
      'async_await_syntax_test_b12e_multi': notyetstrong,
      'async_await_syntax_test_b12f_multi': notyetstrong,
      'async_await_syntax_test_b13b_multi': notyetstrong,
      'async_await_syntax_test_b13d_multi': notyetstrong,
      'async_await_syntax_test_b14b_multi': notyetstrong,
      'async_await_syntax_test_b14d_multi': notyetstrong,
      'async_await_syntax_test_b15b_multi': notyetstrong,
      'async_await_syntax_test_b15d_multi': notyetstrong,
      'async_await_syntax_test_c01b_multi': notyetstrong,
      'async_await_syntax_test_c01c_multi': notyetstrong,
      'async_await_syntax_test_c04b_multi': notyetstrong,
      'async_await_syntax_test_c10a_multi': notyetstrong,
      'async_await_syntax_test_c11a_multi': notyetstrong,
      'async_await_syntax_test_c11b_multi': notyetstrong,
      'async_await_syntax_test_d01b_multi': notyetstrong,
      'async_await_syntax_test_d01c_multi': notyetstrong,
      'async_await_syntax_test_d04b_multi': notyetstrong,
      'async_await_syntax_test_d08b_multi': notyetstrong,
      'async_await_syntax_test_d10a_multi': notyetstrong,
      'async_await_syntax_test_e1_multi': notyetstrong,
      'async_await_syntax_test_e2_multi': notyetstrong,
      'async_await_syntax_test_e3_multi': notyetstrong,
      'async_await_syntax_test_e4_multi': notyetstrong,
      'async_await_syntax_test_e5_multi': notyetstrong,
      'async_await_syntax_test_e6_multi': notyetstrong,
      'async_await_syntax_test_e7_multi': notyetstrong,
      'async_await_syntax_test_e8_multi': notyetstrong,
      'async_await_syntax_test_e9_multi': notyetstrong,
      'async_await_test_02_multi': notyetstrong,
      'async_await_test_03_multi': notyetstrong,
      'async_or_generator_return_type_stacktrace_test_01_multi': notyetstrong,
      'async_or_generator_return_type_stacktrace_test_02_multi': notyetstrong,
      'async_or_generator_return_type_stacktrace_test_03_multi': notyetstrong,
      'async_return_types_test_tooManyTypeParameters_multi': notyetstrong,
      'async_return_types_test_wrongReturnType_multi': notyetstrong,
      'async_return_types_test_wrongTypeParameter_multi': notyetstrong,
      'await_backwards_compatibility_test_await1_multi': notyetstrong,
      'await_backwards_compatibility_test_await2_multi': notyetstrong,
      'await_backwards_compatibility_test_await3_multi': notyetstrong,
      'await_backwards_compatibility_test_await4_multi': notyetstrong,
      'await_test': notyetstrong,
      'bad_constructor_test_00_multi': notyetstrong,
      'bad_constructor_test_01_multi': notyetstrong,
      'bad_constructor_test_04_multi': notyetstrong,
      'bad_constructor_test_05_multi': notyetstrong,
      'bad_constructor_test_06_multi': notyetstrong,
      'bad_constructor_test_none_multi': notyetstrong,
      'bad_named_parameters2_test_01_multi': notyetstrong,
      'bad_named_parameters_test_01_multi': notyetstrong,
      'bad_named_parameters_test_02_multi': notyetstrong,
      'bad_named_parameters_test_03_multi': notyetstrong,
      'bad_named_parameters_test_04_multi': notyetstrong,
      'bad_named_parameters_test_05_multi': notyetstrong,
      'bad_override_test_01_multi': notyetstrong,
      'bad_override_test_02_multi': notyetstrong,
      'bad_override_test_03_multi': notyetstrong,
      'bad_override_test_04_multi': notyetstrong,
      'bad_override_test_05_multi': notyetstrong,
      'bad_override_test_06_multi': notyetstrong,
      'black_listed_test_01_multi': notyetstrong,
      'black_listed_test_02_multi': notyetstrong,
      'black_listed_test_03_multi': notyetstrong,
      'black_listed_test_04_multi': notyetstrong,
      'black_listed_test_05_multi': notyetstrong,
      'black_listed_test_06_multi': notyetstrong,
      'black_listed_test_07_multi': notyetstrong,
      'black_listed_test_08_multi': notyetstrong,
      'black_listed_test_09_multi': notyetstrong,
      'black_listed_test_10_multi': notyetstrong,
      'black_listed_test_12_multi': notyetstrong,
      'black_listed_test_13_multi': notyetstrong,
      'black_listed_test_14_multi': notyetstrong,
      'black_listed_test_none_multi': notyetstrong,
      'bool_check_test': notyetstrong,
      'bound_closure_primitives_test': notyetstrong,
      'built_in_identifier_illegal_test_01_multi': notyetstrong,
      'built_in_identifier_illegal_test_04_multi': notyetstrong,
      'built_in_identifier_illegal_test_05_multi': notyetstrong,
      'built_in_identifier_illegal_test_06_multi': notyetstrong,
      'built_in_identifier_illegal_test_07_multi': notyetstrong,
      'built_in_identifier_illegal_test_08_multi': notyetstrong,
      'built_in_identifier_illegal_test_10_multi': notyetstrong,
      'built_in_identifier_illegal_test_12_multi': notyetstrong,
      'built_in_identifier_illegal_test_13_multi': notyetstrong,
      'built_in_identifier_illegal_test_15_multi': notyetstrong,
      'built_in_identifier_illegal_test_16_multi': notyetstrong,
      'built_in_identifier_illegal_test_17_multi': notyetstrong,
      'built_in_identifier_illegal_test_18_multi': notyetstrong,
      'built_in_identifier_illegal_test_19_multi': notyetstrong,
      'built_in_identifier_illegal_test_20_multi': notyetstrong,
      'built_in_identifier_prefix_test': notyetstrong,
      'call_constructor_on_unresolvable_class_test_01_multi': notyetstrong,
      'call_constructor_on_unresolvable_class_test_02_multi': notyetstrong,
      'call_constructor_on_unresolvable_class_test_03_multi': notyetstrong,
      'call_constructor_on_unresolvable_class_test_04_multi': notyetstrong,
      'call_constructor_on_unresolvable_class_test_05_multi': notyetstrong,
      'call_constructor_on_unresolvable_class_test_06_multi': notyetstrong,
      'call_constructor_on_unresolvable_class_test_07_multi': notyetstrong,
      'call_non_method_field_test_01_multi': notyetstrong,
      'call_non_method_field_test_02_multi': notyetstrong,
      'call_nonexistent_constructor_test_01_multi': notyetstrong,
      'call_nonexistent_constructor_test_02_multi': notyetstrong,
      'call_nonexistent_static_test_01_multi': notyetstrong,
      'call_nonexistent_static_test_02_multi': notyetstrong,
      'call_nonexistent_static_test_03_multi': notyetstrong,
      'call_nonexistent_static_test_04_multi': notyetstrong,
      'call_nonexistent_static_test_05_multi': notyetstrong,
      'call_nonexistent_static_test_06_multi': notyetstrong,
      'call_nonexistent_static_test_07_multi': notyetstrong,
      'call_nonexistent_static_test_08_multi': notyetstrong,
      'call_nonexistent_static_test_09_multi': notyetstrong,
      'call_nonexistent_static_test_10_multi': notyetstrong,
      'call_through_getter_test': notyetstrong,
      'call_type_literal_test_01_multi': notyetstrong,
      'callable_test_00_multi': notyetstrong,
      'callable_test_01_multi': notyetstrong,
      'canonical_const3_test': notyetstrong,
      'cascade_test_01_multi': notyetstrong,
      'cascade_test_02_multi': notyetstrong,
      'cascade_test_03_multi': notyetstrong,
      'cast_test_04_multi': notyetstrong,
      'cast_test_05_multi': notyetstrong,
      'check_member_static_test_01_multi': notyetstrong,
      'check_member_static_test_02_multi': notyetstrong,
      'check_method_override_test_01_multi': notyetstrong,
      'check_method_override_test_02_multi': notyetstrong,
      'checked_null_test_01_multi': notyetstrong,
      'checked_setter2_test': notyetstrong,
      'checked_setter3_test_01_multi': notyetstrong,
      'checked_setter3_test_02_multi': notyetstrong,
      'checked_setter3_test_none_multi': notyetstrong,
      'checked_setter_test': notyetstrong,
      'class_cycle2_test_01_multi': notyetstrong,
      'class_cycle2_test_02_multi': notyetstrong,
      'class_cycle_test_00_multi': notyetstrong,
      'class_cycle_test_01_multi': notyetstrong,
      'class_cycle_test_02_multi': notyetstrong,
      'class_cycle_test_03_multi': notyetstrong,
      'class_keyword_test_01_multi': notyetstrong,
      'class_keyword_test_02_multi': notyetstrong,
      'class_literal_test_01_multi': notyetstrong,
      'class_literal_test_02_multi': notyetstrong,
      'class_literal_test_03_multi': notyetstrong,
      'class_literal_test_04_multi': notyetstrong,
      'class_literal_test_05_multi': notyetstrong,
      'class_literal_test_06_multi': notyetstrong,
      'class_literal_test_07_multi': notyetstrong,
      'class_literal_test_08_multi': notyetstrong,
      'class_literal_test_09_multi': notyetstrong,
      'class_literal_test_10_multi': notyetstrong,
      'class_literal_test_11_multi': notyetstrong,
      'class_literal_test_12_multi': notyetstrong,
      'class_literal_test_13_multi': notyetstrong,
      'class_literal_test_14_multi': notyetstrong,
      'class_literal_test_15_multi': notyetstrong,
      'class_literal_test_16_multi': notyetstrong,
      'class_literal_test_17_multi': notyetstrong,
      'class_literal_test_18_multi': notyetstrong,
      'class_literal_test_19_multi': notyetstrong,
      'class_literal_test_20_multi': notyetstrong,
      'class_literal_test_21_multi': notyetstrong,
      'class_literal_test_22_multi': notyetstrong,
      'class_literal_test_23_multi': notyetstrong,
      'class_literal_test_24_multi': notyetstrong,
      'class_literal_test_25_multi': notyetstrong,
      'class_override_test_00_multi': notyetstrong,
      'class_syntax_test_01_multi': notyetstrong,
      'closure_in_initializer_test': notyetstrong,
      'closure_internals_test': notyetstrong,
      'closure_type_test_01_multi': notyetstrong,
      'closure_type_test_none_multi': notyetstrong,
      'compile_time_constant10_test_01_multi': notyetstrong,
      'compile_time_constant10_test_02_multi': notyetstrong,
      'compile_time_constant13_test_02_multi': notyetstrong,
      'compile_time_constant13_test_03_multi': notyetstrong,
      'compile_time_constant13_test_04_multi': notyetstrong,
      'compile_time_constant13_test_05_multi': notyetstrong,
      'compile_time_constant_arguments_test_01_multi': notyetstrong,
      'compile_time_constant_arguments_test_02_multi': notyetstrong,
      'compile_time_constant_arguments_test_03_multi': notyetstrong,
      'compile_time_constant_arguments_test_04_multi': notyetstrong,
      'compile_time_constant_arguments_test_05_multi': notyetstrong,
      'compile_time_constant_arguments_test_06_multi': notyetstrong,
      'compile_time_constant_c_test_02_multi': notyetstrong,
      'compile_time_constant_c_test_03_multi': notyetstrong,
      'compile_time_constant_checked2_test_01_multi': notyetstrong,
      'compile_time_constant_checked2_test_02_multi': notyetstrong,
      'compile_time_constant_checked2_test_03_multi': notyetstrong,
      'compile_time_constant_checked2_test_04_multi': notyetstrong,
      'compile_time_constant_checked2_test_05_multi': notyetstrong,
      'compile_time_constant_checked2_test_06_multi': notyetstrong,
      'compile_time_constant_checked3_test_01_multi': notyetstrong,
      'compile_time_constant_checked3_test_02_multi': notyetstrong,
      'compile_time_constant_checked3_test_03_multi': notyetstrong,
      'compile_time_constant_checked3_test_04_multi': notyetstrong,
      'compile_time_constant_checked3_test_05_multi': notyetstrong,
      'compile_time_constant_checked3_test_06_multi': notyetstrong,
      'compile_time_constant_checked4_test_01_multi': notyetstrong,
      'compile_time_constant_checked4_test_02_multi': notyetstrong,
      'compile_time_constant_checked4_test_03_multi': notyetstrong,
      'compile_time_constant_checked5_test_03_multi': notyetstrong,
      'compile_time_constant_checked5_test_04_multi': notyetstrong,
      'compile_time_constant_checked5_test_05_multi': notyetstrong,
      'compile_time_constant_checked5_test_06_multi': notyetstrong,
      'compile_time_constant_checked5_test_07_multi': notyetstrong,
      'compile_time_constant_checked5_test_08_multi': notyetstrong,
      'compile_time_constant_checked5_test_09_multi': notyetstrong,
      'compile_time_constant_checked5_test_10_multi': notyetstrong,
      'compile_time_constant_checked5_test_11_multi': notyetstrong,
      'compile_time_constant_checked5_test_12_multi': notyetstrong,
      'compile_time_constant_checked5_test_13_multi': notyetstrong,
      'compile_time_constant_checked5_test_14_multi': notyetstrong,
      'compile_time_constant_checked5_test_15_multi': notyetstrong,
      'compile_time_constant_checked5_test_16_multi': notyetstrong,
      'compile_time_constant_checked5_test_17_multi': notyetstrong,
      'compile_time_constant_checked5_test_18_multi': notyetstrong,
      'compile_time_constant_checked5_test_19_multi': notyetstrong,
      'compile_time_constant_checked5_test_20_multi': notyetstrong,
      'compile_time_constant_checked5_test_21_multi': notyetstrong,
      'compile_time_constant_checked5_test_22_multi': notyetstrong,
      'compile_time_constant_checked5_test_23_multi': notyetstrong,
      'compile_time_constant_checked5_test_24_multi': notyetstrong,
      'compile_time_constant_checked5_test_25_multi': notyetstrong,
      'compile_time_constant_checked_test_01_multi': notyetstrong,
      'compile_time_constant_checked_test_02_multi': notyetstrong,
      'compile_time_constant_checked_test_03_multi': notyetstrong,
      'compile_time_constant_e_test': notyetstrong,
      'compile_time_constant_h_test': notyetstrong,
      'compile_time_constant_k_test_01_multi': notyetstrong,
      'compile_time_constant_k_test_02_multi': notyetstrong,
      'compile_time_constant_k_test_03_multi': notyetstrong,
      'compile_time_constant_o_test_01_multi': notyetstrong,
      'compile_time_constant_o_test_02_multi': notyetstrong,
      'compile_time_constant_p_test_01_multi': notyetstrong,
      'compile_time_constant_r_test_01_multi': notyetstrong,
      'compile_time_constant_r_test_02_multi': notyetstrong,
      'compile_time_constant_r_test_03_multi': notyetstrong,
      'compile_time_constant_test_01_multi': notyetstrong,
      'compile_time_constant_test_02_multi': notyetstrong,
      'conditional_method_invocation_test_05_multi': notyetstrong,
      'conditional_method_invocation_test_06_multi': notyetstrong,
      'conditional_method_invocation_test_07_multi': notyetstrong,
      'conditional_method_invocation_test_08_multi': notyetstrong,
      'conditional_method_invocation_test_11_multi': notyetstrong,
      'conditional_method_invocation_test_12_multi': notyetstrong,
      'conditional_method_invocation_test_13_multi': notyetstrong,
      'conditional_method_invocation_test_18_multi': notyetstrong,
      'conditional_method_invocation_test_19_multi': notyetstrong,
      'conditional_property_access_test_04_multi': notyetstrong,
      'conditional_property_access_test_05_multi': notyetstrong,
      'conditional_property_access_test_06_multi': notyetstrong,
      'conditional_property_access_test_09_multi': notyetstrong,
      'conditional_property_access_test_10_multi': notyetstrong,
      'conditional_property_access_test_11_multi': notyetstrong,
      'conditional_property_access_test_16_multi': notyetstrong,
      'conditional_property_access_test_17_multi': notyetstrong,
      'conditional_property_assignment_test_04_multi': notyetstrong,
      'conditional_property_assignment_test_05_multi': notyetstrong,
      'conditional_property_assignment_test_06_multi': notyetstrong,
      'conditional_property_assignment_test_10_multi': notyetstrong,
      'conditional_property_assignment_test_11_multi': notyetstrong,
      'conditional_property_assignment_test_12_multi': notyetstrong,
      'conditional_property_assignment_test_13_multi': notyetstrong,
      'conditional_property_assignment_test_20_multi': notyetstrong,
      'conditional_property_assignment_test_21_multi': notyetstrong,
      'conditional_property_assignment_test_22_multi': notyetstrong,
      'conditional_property_assignment_test_27_multi': notyetstrong,
      'conditional_property_assignment_test_28_multi': notyetstrong,
      'conditional_property_assignment_test_32_multi': notyetstrong,
      'conditional_property_assignment_test_33_multi': notyetstrong,
      'conditional_property_assignment_test_34_multi': notyetstrong,
      'conditional_property_assignment_test_35_multi': notyetstrong,
      'conditional_property_increment_decrement_test_04_multi': notyetstrong,
      'conditional_property_increment_decrement_test_08_multi': notyetstrong,
      'conditional_property_increment_decrement_test_12_multi': notyetstrong,
      'conditional_property_increment_decrement_test_16_multi': notyetstrong,
      'conditional_property_increment_decrement_test_21_multi': notyetstrong,
      'conditional_property_increment_decrement_test_22_multi': notyetstrong,
      'conditional_property_increment_decrement_test_27_multi': notyetstrong,
      'conditional_property_increment_decrement_test_28_multi': notyetstrong,
      'conditional_property_increment_decrement_test_33_multi': notyetstrong,
      'conditional_property_increment_decrement_test_34_multi': notyetstrong,
      'conditional_property_increment_decrement_test_39_multi': notyetstrong,
      'conditional_property_increment_decrement_test_40_multi': notyetstrong,
      'const_conditional_test_01_multi': notyetstrong,
      'const_conditional_test_02_multi': notyetstrong,
      'const_conditional_test_03_multi': notyetstrong,
      'const_conditional_test_04_multi': notyetstrong,
      'const_conditional_test_05_multi': notyetstrong,
      'const_conditional_test_06_multi': notyetstrong,
      'const_conditional_test_07_multi': notyetstrong,
      'const_conditional_test_08_multi': notyetstrong,
      'const_conditional_test_09_multi': notyetstrong,
      'const_conditional_test_10_multi': notyetstrong,
      'const_constructor2_test_01_multi': notyetstrong,
      'const_constructor2_test_02_multi': notyetstrong,
      'const_constructor2_test_03_multi': notyetstrong,
      'const_constructor2_test_04_multi': notyetstrong,
      'const_constructor2_test_05_multi': notyetstrong,
      'const_constructor2_test_06_multi': notyetstrong,
      'const_constructor2_test_07_multi': notyetstrong,
      'const_constructor2_test_08_multi': notyetstrong,
      'const_constructor2_test_09_multi': notyetstrong,
      'const_constructor2_test_10_multi': notyetstrong,
      'const_constructor2_test_11_multi': notyetstrong,
      'const_constructor2_test_12_multi': notyetstrong,
      'const_constructor2_test_13_multi': notyetstrong,
      'const_constructor2_test_14_multi': notyetstrong,
      'const_constructor2_test_15_multi': notyetstrong,
      'const_constructor2_test_16_multi': notyetstrong,
      'const_constructor2_test_17_multi': notyetstrong,
      'const_constructor2_test_18_multi': notyetstrong,
      'const_constructor2_test_19_multi': notyetstrong,
      'const_constructor2_test_20_multi': notyetstrong,
      'const_constructor2_test_21_multi': notyetstrong,
      'const_constructor2_test_22_multi': notyetstrong,
      'const_constructor2_test_23_multi': notyetstrong,
      'const_constructor2_test_24_multi': notyetstrong,
      'const_constructor2_test_none_multi': notyetstrong,
      'const_constructor3_test_02_multi': notyetstrong,
      'const_constructor3_test_04_multi': notyetstrong,
      'const_constructor_mixin2_test_01_multi': notyetstrong,
      'const_constructor_mixin3_test_01_multi': notyetstrong,
      'const_constructor_mixin_test_01_multi': notyetstrong,
      'const_constructor_nonconst_field_test_01_multi': notyetstrong,
      'const_constructor_super_test_01_multi': notyetstrong,
      'const_constructor_super_test_02_multi': notyetstrong,
      'const_constructor_syntax_test_01_multi': notyetstrong,
      'const_constructor_syntax_test_02_multi': notyetstrong,
      'const_constructor_syntax_test_03_multi': notyetstrong,
      'const_constructor_syntax_test_04_multi': notyetstrong,
      'const_constructor_syntax_test_05_multi': notyetstrong,
      'const_constructor_test_01_multi': notyetstrong,
      'const_dynamic_type_literal_test_02_multi': notyetstrong,
      'const_error_multiply_initialized_test_01_multi': notyetstrong,
      'const_error_multiply_initialized_test_02_multi': notyetstrong,
      'const_error_multiply_initialized_test_03_multi': notyetstrong,
      'const_error_multiply_initialized_test_04_multi': notyetstrong,
      'const_factory_with_body_test_01_multi': notyetstrong,
      'const_init2_test_02_multi': notyetstrong,
      'const_instance_field_test_01_multi': notyetstrong,
      'const_list_test': notyetstrong,
      'const_map2_test_00_multi': notyetstrong,
      'const_map2_test_none_multi': notyetstrong,
      'const_map3_test_00_multi': notyetstrong,
      'const_map3_test_none_multi': notyetstrong,
      'const_native_factory_test_01_multi': notyetstrong,
      'const_objects_are_immutable_test_01_multi': notyetstrong,
      'const_objects_are_immutable_test_none_multi': notyetstrong,
      'const_redirecting_factory_test': notyetstrong,
      'const_switch2_test_01_multi': notyetstrong,
      'const_syntax_test_01_multi': notyetstrong,
      'const_syntax_test_02_multi': notyetstrong,
      'const_syntax_test_03_multi': notyetstrong,
      'const_syntax_test_04_multi': notyetstrong,
      'const_syntax_test_05_multi': notyetstrong,
      'const_syntax_test_06_multi': notyetstrong,
      'const_syntax_test_07_multi': notyetstrong,
      'const_syntax_test_08_multi': notyetstrong,
      'const_syntax_test_09_multi': notyetstrong,
      'const_syntax_test_10_multi': notyetstrong,
      'const_syntax_test_11_multi': notyetstrong,
      'const_syntax_test_12_multi': notyetstrong,
      'const_types_test_01_multi': notyetstrong,
      'const_types_test_02_multi': notyetstrong,
      'const_types_test_03_multi': notyetstrong,
      'const_types_test_04_multi': notyetstrong,
      'const_types_test_05_multi': notyetstrong,
      'const_types_test_06_multi': notyetstrong,
      'const_types_test_07_multi': notyetstrong,
      'const_types_test_08_multi': notyetstrong,
      'const_types_test_09_multi': notyetstrong,
      'const_types_test_10_multi': notyetstrong,
      'const_types_test_11_multi': notyetstrong,
      'const_types_test_12_multi': notyetstrong,
      'const_types_test_13_multi': notyetstrong,
      'const_types_test_14_multi': notyetstrong,
      'const_types_test_15_multi': notyetstrong,
      'const_types_test_16_multi': notyetstrong,
      'const_types_test_17_multi': notyetstrong,
      'const_types_test_18_multi': notyetstrong,
      'const_types_test_19_multi': notyetstrong,
      'const_types_test_20_multi': notyetstrong,
      'const_types_test_21_multi': notyetstrong,
      'const_types_test_22_multi': notyetstrong,
      'const_types_test_23_multi': notyetstrong,
      'const_types_test_24_multi': notyetstrong,
      'const_types_test_25_multi': notyetstrong,
      'const_types_test_26_multi': notyetstrong,
      'const_types_test_27_multi': notyetstrong,
      'const_types_test_28_multi': notyetstrong,
      'const_types_test_29_multi': notyetstrong,
      'const_types_test_30_multi': notyetstrong,
      'const_types_test_31_multi': notyetstrong,
      'const_types_test_32_multi': notyetstrong,
      'const_types_test_33_multi': notyetstrong,
      'const_types_test_34_multi': notyetstrong,
      'const_types_test_35_multi': notyetstrong,
      'const_types_test_36_multi': notyetstrong,
      'const_types_test_37_multi': notyetstrong,
      'const_types_test_38_multi': notyetstrong,
      'const_types_test_39_multi': notyetstrong,
      'const_types_test_40_multi': notyetstrong,
      'const_types_test_41_multi': notyetstrong,
      'constant_fold_equals_test': notyetstrong,
      'constant_locals_test_01_multi': notyetstrong,
      'constant_locals_test_02_multi': notyetstrong,
      'constant_locals_test_03_multi': notyetstrong,
      'constant_locals_test_04_multi': notyetstrong,
      'constant_locals_test_05_multi': notyetstrong,
      'constant_type_literal_test_01_multi': notyetstrong,
      'constructor10_test_00_multi': notyetstrong,
      'constructor10_test_01_multi': notyetstrong,
      'constructor10_test_02_multi': notyetstrong,
      'constructor2_test': notyetstrong,
      'constructor3_test': notyetstrong,
      'constructor5_test': notyetstrong,
      'constructor6_test': notyetstrong,
      'constructor_call_as_function_test_01_multi': notyetstrong,
      'constructor_duplicate_final_test_01_multi': notyetstrong,
      'constructor_duplicate_final_test_02_multi': notyetstrong,
      'constructor_duplicate_final_test_03_multi': notyetstrong,
      'constructor_duplicate_initializers_test_01_multi': notyetstrong,
      'constructor_duplicate_initializers_test_02_multi': notyetstrong,
      'constructor_duplicate_initializers_test_03_multi': notyetstrong,
      'constructor_initializer_test_01_multi': notyetstrong,
      'constructor_initializer_test_none_multi': notyetstrong,
      'constructor_name_test_01_multi': notyetstrong,
      'constructor_name_test_02_multi': notyetstrong,
      'constructor_name_test_03_multi': notyetstrong,
      'constructor_named_arguments_test_01_multi': notyetstrong,
      'constructor_redirect2_test_01_multi': notyetstrong,
      'constructor_redirect2_test_02_multi': notyetstrong,
      'constructor_redirect2_test_03_multi': notyetstrong,
      'constructor_redirect2_test_04_multi': notyetstrong,
      'constructor_redirect_test_01_multi': notyetstrong,
      'constructor_return_test_01_multi': notyetstrong,
      'constructor_return_test_02_multi': notyetstrong,
      'constructor_return_test_03_multi': notyetstrong,
      'constructor_return_test_04_multi': notyetstrong,
      'constructor_return_test_05_multi': notyetstrong,
      'constructor_test': notyetstrong,
      'constructor_with_mixin_test': notyetstrong,
      'crash_6725_test_01_multi': notyetstrong,
      'create_unresolved_type_test_01_multi': notyetstrong,
      'cyclic_class_member_test_01_multi': notyetstrong,
      'cyclic_constructor_test_01_multi': notyetstrong,
      'cyclic_default_values_test': notyetstrong,
      'cyclic_type_variable_test_01_multi': notyetstrong,
      'cyclic_type_variable_test_02_multi': notyetstrong,
      'cyclic_type_variable_test_03_multi': notyetstrong,
      'cyclic_type_variable_test_04_multi': notyetstrong,
      'cyclic_typedef_test_01_multi': notyetstrong,
      'cyclic_typedef_test_02_multi': notyetstrong,
      'cyclic_typedef_test_03_multi': notyetstrong,
      'cyclic_typedef_test_04_multi': notyetstrong,
      'cyclic_typedef_test_05_multi': notyetstrong,
      'cyclic_typedef_test_06_multi': notyetstrong,
      'cyclic_typedef_test_07_multi': notyetstrong,
      'cyclic_typedef_test_08_multi': notyetstrong,
      'cyclic_typedef_test_09_multi': notyetstrong,
      'cyclic_typedef_test_10_multi': notyetstrong,
      'cyclic_typedef_test_11_multi': notyetstrong,
      'cyclic_typedef_test_13_multi': notyetstrong,
      'default_factory2_test_01_multi': notyetstrong,
      'default_factory2_test_none_multi': notyetstrong,
      'default_factory_library_test': notyetstrong,
      'default_factory_test_01_multi': notyetstrong,
      'deferred_constraints_constants_test_constructor1_multi': notyetstrong,
      'deferred_constraints_constants_test_constructor2_multi': notyetstrong,
      'deferred_constraints_constants_test_default_argument1_multi': notyetstrong,
      'deferred_constraints_constants_test_default_argument2_multi': notyetstrong,
      'deferred_constraints_constants_test_metadata1_multi': notyetstrong,
      'deferred_constraints_constants_test_metadata2_multi': notyetstrong,
      'deferred_constraints_constants_test_metadata3_multi': notyetstrong,
      'deferred_constraints_constants_test_reference1_multi': notyetstrong,
      'deferred_constraints_constants_test_reference2_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_as_operation_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_catch_check_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_is_check_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_new_before_load_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_new_generic2_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_new_generic3_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_type_annotation1_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_type_annotation_generic1_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_type_annotation_generic2_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_type_annotation_generic3_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_type_annotation_generic4_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_type_annotation_null_multi': notyetstrong,
      'deferred_constraints_type_annotation_test_type_annotation_top_level_multi': notyetstrong,
      'deferred_duplicate_prefix1_test_01_multi': notyetstrong,
      'deferred_duplicate_prefix2_test_01_multi': notyetstrong,
      'deferred_duplicate_prefix3_test_01_multi': notyetstrong,
      'deferred_global_test': notyetstrong,
      'deferred_inheritance_constraints_test_extends_multi': notyetstrong,
      'deferred_inheritance_constraints_test_implements_multi': notyetstrong,
      'deferred_inheritance_constraints_test_mixin_multi': notyetstrong,
      'deferred_inheritance_constraints_test_redirecting_constructor_multi': notyetstrong,
      'deferred_load_constants_test_01_multi': notyetstrong,
      'deferred_load_constants_test_02_multi': notyetstrong,
      'deferred_load_constants_test_03_multi': notyetstrong,
      'deferred_load_constants_test_04_multi': notyetstrong,
      'deferred_load_constants_test_05_multi': notyetstrong,
      'deferred_no_prefix_test_01_multi': notyetstrong,
      'deopt_inlined_function_test': notyetstrong,
      'double_to_string_as_exponential2_test': notyetstrong,
      'double_to_string_as_fixed2_test': notyetstrong,
      'double_to_string_as_precision2_test': notyetstrong,
      'duplicate_constructor_test_01_multi': notyetstrong,
      'duplicate_implements_test_01_multi': notyetstrong,
      'duplicate_implements_test_02_multi': notyetstrong,
      'duplicate_implements_test_03_multi': notyetstrong,
      'duplicate_implements_test_04_multi': notyetstrong,
      'dynamic2_test_00_multi': notyetstrong,
      'dynamic2_test_01_multi': notyetstrong,
      'dynamic_field_test_01_multi': notyetstrong,
      'dynamic_field_test_02_multi': notyetstrong,
      'dynamic_prefix_core_test_01_multi': notyetstrong,
      'emit_const_fields_test': notyetstrong,
      'empty_block_case_test': notyetstrong,
      'enum_is_keyword_test_01_multi': notyetstrong,
      'enum_private_test_02_multi': notyetstrong,
      'enum_syntax_test_01_multi': notyetstrong,
      'enum_syntax_test_02_multi': notyetstrong,
      'enum_syntax_test_03_multi': notyetstrong,
      'enum_syntax_test_04_multi': notyetstrong,
      'enum_syntax_test_07_multi': notyetstrong,
      'enum_syntax_test_08_multi': notyetstrong,
      'enum_syntax_test_09_multi': notyetstrong,
      'enum_syntax_test_10_multi': notyetstrong,
      'enum_syntax_test_11_multi': notyetstrong,
      'enum_syntax_test_20_multi': notyetstrong,
      'enum_syntax_test_21_multi': notyetstrong,
      'enum_syntax_test_22_multi': notyetstrong,
      'enum_syntax_test_30_multi': notyetstrong,
      'error_stacktrace_test': notyetstrong,
      'example_constructor_test': notyetstrong,
      'export_double_same_main_test': notyetstrong,
      'export_main_override_test': notyetstrong,
      'export_main_test': notyetstrong,
      'external_test_01_multi': notyetstrong,
      'external_test_02_multi': notyetstrong,
      'external_test_11_multi': notyetstrong,
      'external_test_12_multi': notyetstrong,
      'external_test_14_multi': notyetstrong,
      'external_test_16_multi': notyetstrong,
      'external_test_22_multi': notyetstrong,
      'external_test_23_multi': notyetstrong,
      'external_test_25_multi': notyetstrong,
      'external_test_30_multi': notyetstrong,
      'external_test_31_multi': notyetstrong,
      'f_bounded_quantification2_test': notyetstrong,
      'f_bounded_quantification4_test': notyetstrong,
      'f_bounded_quantification5_test': notyetstrong,
      'f_bounded_quantification_test_01_multi': notyetstrong,
      'f_bounded_quantification_test_02_multi': notyetstrong,
      'f_bounded_quantification_test_none_multi': notyetstrong,
      'factory1_test_00_multi': notyetstrong,
      'factory1_test_01_multi': notyetstrong,
      'factory1_test_none_multi': notyetstrong,
      'factory2_test': notyetstrong,
      'factory3_test': notyetstrong,
      'factory4_test': notyetstrong,
      'factory5_test_00_multi': notyetstrong,
      'factory5_test_none_multi': notyetstrong,
      'factory_implementation_test_00_multi': notyetstrong,
      'factory_implementation_test_none_multi': notyetstrong,
      'factory_redirection2_test_01_multi': notyetstrong,
      'factory_redirection3_cyclic_test_01_multi': notyetstrong,
      'factory_redirection_test_01_multi': notyetstrong,
      'factory_redirection_test_02_multi': notyetstrong,
      'factory_redirection_test_03_multi': notyetstrong,
      'factory_redirection_test_04_multi': notyetstrong,
      'factory_redirection_test_05_multi': notyetstrong,
      'factory_redirection_test_06_multi': notyetstrong,
      'factory_redirection_test_07_multi': notyetstrong,
      'factory_redirection_test_08_multi': notyetstrong,
      'factory_redirection_test_09_multi': notyetstrong,
      'factory_redirection_test_10_multi': notyetstrong,
      'factory_redirection_test_11_multi': notyetstrong,
      'factory_redirection_test_12_multi': notyetstrong,
      'factory_redirection_test_13_multi': notyetstrong,
      'factory_redirection_test_14_multi': notyetstrong,
      'factory_redirection_test_none_multi': notyetstrong,
      'factory_return_type_checked_test': notyetstrong,
      'fauxverride_test_03_multi': notyetstrong,
      'fauxverride_test_05_multi': notyetstrong,
      'field_decl_missing_var_type_test_01_multi': notyetstrong,
      'field_initialization_order_test': notyetstrong,
      'field_override2_test': notyetstrong,
      'field_override3_test_00_multi': notyetstrong,
      'field_override3_test_01_multi': notyetstrong,
      'field_override3_test_02_multi': notyetstrong,
      'field_override3_test_03_multi': notyetstrong,
      'field_override4_test_00_multi': notyetstrong,
      'field_override4_test_02_multi': notyetstrong,
      'field_override_test_01_multi': notyetstrong,
      'field_override_test_02_multi': notyetstrong,
      'field_override_test_none_multi': notyetstrong,
      'field_test': notyetstrong,
      'field_type_check_test_01_multi': notyetstrong,
      'final_field_initialization_order_test': notyetstrong,
      'final_for_in_variable_test_01_multi': notyetstrong,
      'final_is_not_const_test_01_multi': notyetstrong,
      'final_param_test_01_multi': notyetstrong,
      'final_super_field_set_test_01_multi': notyetstrong,
      'final_syntax_test_09_multi': notyetstrong,
      'final_syntax_test_10_multi': notyetstrong,
      'final_variable_assignment_test_01_multi': notyetstrong,
      'final_variable_assignment_test_02_multi': notyetstrong,
      'final_variable_assignment_test_03_multi': notyetstrong,
      'final_variable_assignment_test_04_multi': notyetstrong,
      'first_class_types_literals_test_03_multi': notyetstrong,
      'first_class_types_literals_test_04_multi': notyetstrong,
      'first_class_types_literals_test_05_multi': notyetstrong,
      'first_class_types_literals_test_06_multi': notyetstrong,
      'first_class_types_literals_test_07_multi': notyetstrong,
      'first_class_types_literals_test_08_multi': notyetstrong,
      'first_class_types_literals_test_09_multi': notyetstrong,
      'first_class_types_literals_test_10_multi': notyetstrong,
      'first_class_types_literals_test_11_multi': notyetstrong,
      'first_class_types_literals_test_12_multi': notyetstrong,
      'for_in_side_effects_test': notyetstrong,
      'function_literals2_test': notyetstrong,
      'function_literals_test': notyetstrong,
      'function_malformed_result_type_test': notyetstrong,
      'function_subtype_bound_closure7_test': notyetstrong,
      'function_subtype_checked0_test': notyetstrong,
      'function_subtype_closure0_test': notyetstrong,
      'function_subtype_closure1_test': notyetstrong,
      'function_subtype_factory1_test': notyetstrong,
      'function_subtype_inline1_test': notyetstrong,
      'function_subtype_inline2_test': notyetstrong,
      'function_subtype_setter0_test': notyetstrong,
      'function_syntax_test_00_multi': notyetstrong,
      'function_syntax_test_01_multi': notyetstrong,
      'function_syntax_test_02_multi': notyetstrong,
      'function_syntax_test_03_multi': notyetstrong,
      'function_syntax_test_04_multi': notyetstrong,
      'function_syntax_test_05_multi': notyetstrong,
      'function_syntax_test_06_multi': notyetstrong,
      'function_syntax_test_07_multi': notyetstrong,
      'function_syntax_test_08_multi': notyetstrong,
      'function_syntax_test_09_multi': notyetstrong,
      'function_syntax_test_10_multi': notyetstrong,
      'function_syntax_test_11_multi': notyetstrong,
      'function_syntax_test_12_multi': notyetstrong,
      'function_syntax_test_13_multi': notyetstrong,
      'function_syntax_test_14_multi': notyetstrong,
      'function_syntax_test_15_multi': notyetstrong,
      'function_syntax_test_16_multi': notyetstrong,
      'function_syntax_test_17_multi': notyetstrong,
      'function_syntax_test_18_multi': notyetstrong,
      'function_syntax_test_19_multi': notyetstrong,
      'function_syntax_test_20_multi': notyetstrong,
      'function_syntax_test_21_multi': notyetstrong,
      'function_syntax_test_22_multi': notyetstrong,
      'function_syntax_test_23_multi': notyetstrong,
      'function_syntax_test_24_multi': notyetstrong,
      'function_syntax_test_25_multi': notyetstrong,
      'function_syntax_test_26_multi': notyetstrong,
      'function_syntax_test_27_multi': notyetstrong,
      'function_syntax_test_28_multi': notyetstrong,
      'function_syntax_test_29_multi': notyetstrong,
      'function_syntax_test_30_multi': notyetstrong,
      'function_syntax_test_31_multi': notyetstrong,
      'function_syntax_test_32_multi': notyetstrong,
      'function_syntax_test_33_multi': notyetstrong,
      'function_syntax_test_34_multi': notyetstrong,
      'function_syntax_test_35_multi': notyetstrong,
      'function_syntax_test_36_multi': notyetstrong,
      'function_syntax_test_37_multi': notyetstrong,
      'function_syntax_test_44_multi': notyetstrong,
      'function_syntax_test_45_multi': notyetstrong,
      'function_syntax_test_46_multi': notyetstrong,
      'function_syntax_test_47_multi': notyetstrong,
      'function_syntax_test_48_multi': notyetstrong,
      'function_syntax_test_49_multi': notyetstrong,
      'function_syntax_test_50_multi': notyetstrong,
      'function_syntax_test_51_multi': notyetstrong,
      'function_syntax_test_52_multi': notyetstrong,
      'function_syntax_test_53_multi': notyetstrong,
      'function_syntax_test_54_multi': notyetstrong,
      'function_syntax_test_55_multi': notyetstrong,
      'function_syntax_test_64_multi': notyetstrong,
      'function_syntax_test_65_multi': notyetstrong,
      'function_syntax_test_66_multi': notyetstrong,
      'function_syntax_test_67_multi': notyetstrong,
      'function_syntax_test_68_multi': notyetstrong,
      'function_syntax_test_69_multi': notyetstrong,
      'function_syntax_test_70_multi': notyetstrong,
      'function_syntax_test_71_multi': notyetstrong,
      'function_syntax_test_72_multi': notyetstrong,
      'function_syntax_test_73_multi': notyetstrong,
      'function_syntax_test_74_multi': notyetstrong,
      'function_test': notyetstrong,
      'function_type2_test': notyetstrong,
      'function_type_alias5_test_00_multi': notyetstrong,
      'function_type_alias5_test_01_multi': notyetstrong,
      'function_type_alias5_test_02_multi': notyetstrong,
      'function_type_alias6_test_00_multi': notyetstrong,
      'function_type_alias7_test_00_multi': notyetstrong,
      'function_type_alias7_test_01_multi': notyetstrong,
      'function_type_alias7_test_02_multi': notyetstrong,
      'function_type_alias9_test_00_multi': notyetstrong,
      'function_type_call_getter2_test_00_multi': notyetstrong,
      'function_type_call_getter2_test_01_multi': notyetstrong,
      'function_type_call_getter2_test_02_multi': notyetstrong,
      'function_type_call_getter2_test_03_multi': notyetstrong,
      'function_type_call_getter2_test_04_multi': notyetstrong,
      'function_type_call_getter2_test_05_multi': notyetstrong,
      'function_type_test': notyetstrong,
      'generic_closure_test': notyetstrong,
      'generic_constructor_mixin2_test': notyetstrong,
      'generic_constructor_mixin3_test': notyetstrong,
      'generic_constructor_mixin_test': notyetstrong,
      'generic_field_mixin6_test_01_multi': notyetstrong,
      'generic_field_mixin6_test_none_multi': notyetstrong,
      'generic_instanceof_test': notyetstrong,
      'generic_list_checked_test': notyetstrong,
      'generic_test': notyetstrong,
      'generics_test': notyetstrong,
      'get_set_syntax_test_00_multi': notyetstrong,
      'get_set_syntax_test_01_multi': notyetstrong,
      'get_set_syntax_test_02_multi': notyetstrong,
      'get_set_syntax_test_03_multi': notyetstrong,
      'get_set_syntax_test_04_multi': notyetstrong,
      'get_set_syntax_test_05_multi': notyetstrong,
      'get_set_syntax_test_06_multi': notyetstrong,
      'get_set_syntax_test_07_multi': notyetstrong,
      'get_set_syntax_test_09_multi': notyetstrong,
      'get_set_syntax_test_10_multi': notyetstrong,
      'get_set_syntax_test_11_multi': notyetstrong,
      'get_set_syntax_test_13_multi': notyetstrong,
      'get_set_syntax_test_14_multi': notyetstrong,
      'get_set_syntax_test_15_multi': notyetstrong,
      'get_set_syntax_test_none_multi': notyetstrong,
      'getter_no_setter2_test_00_multi': notyetstrong,
      'getter_no_setter2_test_01_multi': notyetstrong,
      'getter_no_setter2_test_02_multi': notyetstrong,
      'getter_no_setter2_test_03_multi': notyetstrong,
      'getter_no_setter_test_00_multi': notyetstrong,
      'getter_no_setter_test_01_multi': notyetstrong,
      'getter_no_setter_test_02_multi': notyetstrong,
      'getter_no_setter_test_none_multi': notyetstrong,
      'getter_override2_test_02_multi': notyetstrong,
      'getter_override_test_00_multi': notyetstrong,
      'getter_override_test_01_multi': notyetstrong,
      'getter_override_test_02_multi': notyetstrong,
      'getter_override_test_03_multi': notyetstrong,
      'getter_parameters_test_01_multi': notyetstrong,
      'getter_parameters_test_02_multi': notyetstrong,
      'getter_parameters_test_03_multi': notyetstrong,
      'getter_parameters_test_04_multi': notyetstrong,
      'getter_setter_in_lib_test': notyetstrong,
      'getters_setters2_test_02_multi': notyetstrong,
      'getters_setters2_test_03_multi': notyetstrong,
      'hello_script_test': notyetstrong,
      'hidden_import_test_01_multi': notyetstrong,
      'hidden_import_test_02_multi': notyetstrong,
      'identical_const_test_01_multi': notyetstrong,
      'identical_const_test_02_multi': notyetstrong,
      'identical_const_test_03_multi': notyetstrong,
      'identical_const_test_04_multi': notyetstrong,
      'if_null_assignment_behavior_test_03_multi': notyetstrong,
      'if_null_assignment_behavior_test_04_multi': notyetstrong,
      'if_null_assignment_behavior_test_13_multi': notyetstrong,
      'if_null_assignment_behavior_test_14_multi': notyetstrong,
      'if_null_assignment_behavior_test_15_multi': notyetstrong,
      'if_null_assignment_behavior_test_29_multi': notyetstrong,
      'if_null_assignment_behavior_test_30_multi': notyetstrong,
      'if_null_assignment_static_test_02_multi': notyetstrong,
      'if_null_assignment_static_test_04_multi': notyetstrong,
      'if_null_assignment_static_test_05_multi': notyetstrong,
      'if_null_assignment_static_test_06_multi': notyetstrong,
      'if_null_assignment_static_test_07_multi': notyetstrong,
      'if_null_assignment_static_test_09_multi': notyetstrong,
      'if_null_assignment_static_test_11_multi': notyetstrong,
      'if_null_assignment_static_test_12_multi': notyetstrong,
      'if_null_assignment_static_test_13_multi': notyetstrong,
      'if_null_assignment_static_test_14_multi': notyetstrong,
      'if_null_assignment_static_test_16_multi': notyetstrong,
      'if_null_assignment_static_test_18_multi': notyetstrong,
      'if_null_assignment_static_test_19_multi': notyetstrong,
      'if_null_assignment_static_test_20_multi': notyetstrong,
      'if_null_assignment_static_test_21_multi': notyetstrong,
      'if_null_assignment_static_test_23_multi': notyetstrong,
      'if_null_assignment_static_test_25_multi': notyetstrong,
      'if_null_assignment_static_test_26_multi': notyetstrong,
      'if_null_assignment_static_test_27_multi': notyetstrong,
      'if_null_assignment_static_test_28_multi': notyetstrong,
      'if_null_assignment_static_test_30_multi': notyetstrong,
      'if_null_assignment_static_test_32_multi': notyetstrong,
      'if_null_assignment_static_test_33_multi': notyetstrong,
      'if_null_assignment_static_test_34_multi': notyetstrong,
      'if_null_assignment_static_test_35_multi': notyetstrong,
      'if_null_assignment_static_test_37_multi': notyetstrong,
      'if_null_assignment_static_test_39_multi': notyetstrong,
      'if_null_assignment_static_test_40_multi': notyetstrong,
      'if_null_assignment_static_test_41_multi': notyetstrong,
      'if_null_assignment_static_test_42_multi': notyetstrong,
      'if_null_behavior_test_06_multi': notyetstrong,
      'if_null_behavior_test_07_multi': notyetstrong,
      'if_null_behavior_test_09_multi': notyetstrong,
      'if_null_behavior_test_10_multi': notyetstrong,
      'if_null_behavior_test_12_multi': notyetstrong,
      'if_null_behavior_test_13_multi': notyetstrong,
      'if_null_behavior_test_14_multi': notyetstrong,
      'if_null_behavior_test_15_multi': notyetstrong,
      'if_null_behavior_test_16_multi': notyetstrong,
      'if_null_precedence_test_01_multi': notyetstrong,
      'if_null_precedence_test_02_multi': notyetstrong,
      'if_null_precedence_test_03_multi': notyetstrong,
      'if_null_precedence_test_04_multi': notyetstrong,
      'if_null_precedence_test_05_multi': notyetstrong,
      'if_null_precedence_test_06_multi': notyetstrong,
      'if_null_precedence_test_07_multi': notyetstrong,
      'if_null_precedence_test_08_multi': notyetstrong,
      'if_null_precedence_test_none_multi': notyetstrong,
      'illegal_declaration_test_01_multi': notyetstrong,
      'illegal_initializer_test_01_multi': notyetstrong,
      'illegal_initializer_test_02_multi': notyetstrong,
      'illegal_initializer_test_03_multi': notyetstrong,
      'illegal_initializer_test_04_multi': notyetstrong,
      'illegal_invocation_test_01_multi': notyetstrong,
      'implicit_this_test_01_multi': notyetstrong,
      'implicit_this_test_02_multi': notyetstrong,
      'implicit_this_test_04_multi': notyetstrong,
      'implicit_this_test_none_multi': notyetstrong,
      'implied_interface_test': notyetstrong,
      'import_combinators_test': notyetstrong,
      'import_core_prefix_test': notyetstrong,
      'import_self_test_01_multi': notyetstrong,
      'inference_captured_variable2_test': notyetstrong,
      'inference_captured_variable_test': notyetstrong,
      'inferrer_constructor5_test_01_multi': notyetstrong,
      'inferrer_this_access_test': notyetstrong,
      'inline_effect_context_test': notyetstrong,
      'inline_in_for_initializer_and_bailout_test': notyetstrong,
      'inline_super_test': notyetstrong,
      'inline_test_context_test': notyetstrong,
      'inline_value_context_test': notyetstrong,
      'inlined_throw_test': notyetstrong,
      'instanceof3_test': notyetstrong,
      'instantiate_type_variable_test_01_multi': notyetstrong,
      'interceptor2_test': notyetstrong,
      'interceptor3_test': notyetstrong,
      'interceptor6_test': notyetstrong,
      'interceptor7_test': notyetstrong,
      'interceptor_test': notyetstrong,
      'interface_cycle_test_01_multi': notyetstrong,
      'interface_cycle_test_02_multi': notyetstrong,
      'interface_test_00_multi': notyetstrong,
      'interface_test_none_multi': notyetstrong,
      'internal_library_test_02_multi': notyetstrong,
      'invocation_mirror2_test': notyetstrong,
      'invocation_mirror_invoke_on2_test': notyetstrong,
      'invocation_mirror_invoke_on_test': notyetstrong,
      'invocation_mirror_test': notyetstrong,
      'is_function_test': notyetstrong,
      'is_malformed_type_test_94_multi': notyetstrong,
      'is_malformed_type_test_95_multi': notyetstrong,
      'is_malformed_type_test_96_multi': notyetstrong,
      'is_malformed_type_test_97_multi': notyetstrong,
      'is_malformed_type_test_98_multi': notyetstrong,
      'is_malformed_type_test_99_multi': notyetstrong,
      'is_not_class2_test': notyetstrong,
      'is_object_test': notyetstrong,
      'isnot_malformed_type_test': notyetstrong,
      'issue11724_test': notyetstrong,
      'issue11793_test': notyetstrong,
      'issue13474_test': notyetstrong,
      'issue1363_test': notyetstrong,
      'issue15606_test_01_multi': notyetstrong,
      'issue18628_1_test_01_multi': notyetstrong,
      'issue18628_2_test_01_multi': notyetstrong,
      'issue21159_test': notyetstrong,
      'issue3806_test': notyetstrong,
      'keyword_type_expression_test_01_multi': notyetstrong,
      'keyword_type_expression_test_02_multi': notyetstrong,
      'keyword_type_expression_test_03_multi': notyetstrong,
      'label_test': notyetstrong,
      'lazy_static6_test': notyetstrong,
      'least_upper_bound_expansive_test_01_multi': notyetstrong,
      'least_upper_bound_expansive_test_02_multi': notyetstrong,
      'least_upper_bound_expansive_test_03_multi': notyetstrong,
      'least_upper_bound_expansive_test_04_multi': notyetstrong,
      'least_upper_bound_expansive_test_05_multi': notyetstrong,
      'least_upper_bound_expansive_test_06_multi': notyetstrong,
      'least_upper_bound_expansive_test_07_multi': notyetstrong,
      'least_upper_bound_expansive_test_08_multi': notyetstrong,
      'least_upper_bound_expansive_test_09_multi': notyetstrong,
      'least_upper_bound_expansive_test_10_multi': notyetstrong,
      'least_upper_bound_expansive_test_11_multi': notyetstrong,
      'least_upper_bound_expansive_test_12_multi': notyetstrong,
      'least_upper_bound_test_03_multi': notyetstrong,
      'least_upper_bound_test_04_multi': notyetstrong,
      'least_upper_bound_test_05_multi': notyetstrong,
      'least_upper_bound_test_10_multi': notyetstrong,
      'least_upper_bound_test_19_multi': notyetstrong,
      'least_upper_bound_test_20_multi': notyetstrong,
      'least_upper_bound_test_23_multi': notyetstrong,
      'least_upper_bound_test_24_multi': notyetstrong,
      'least_upper_bound_test_29_multi': notyetstrong,
      'least_upper_bound_test_30_multi': notyetstrong,
      'least_upper_bound_test_32_multi': notyetstrong,
      'library1_test': notyetstrong,
      'library_ambiguous_test_00_multi': notyetstrong,
      'library_ambiguous_test_01_multi': notyetstrong,
      'library_ambiguous_test_02_multi': notyetstrong,
      'library_ambiguous_test_03_multi': notyetstrong,
      'library_ambiguous_test_04_multi': notyetstrong,
      'library_ambiguous_test_05_multi': notyetstrong,
      'library_juxtaposition_test': notyetstrong,
      'library_prefixes_test': notyetstrong,
      'list_double_index_in_loop2_test': notyetstrong,
      'list_double_index_in_loop_test': notyetstrong,
      'list_literal1_test_01_multi': notyetstrong,
      'list_literal4_test': notyetstrong,
      'list_literal_syntax_test_00_multi': notyetstrong,
      'list_literal_syntax_test_01_multi': notyetstrong,
      'list_literal_syntax_test_02_multi': notyetstrong,
      'list_literal_syntax_test_03_multi': notyetstrong,
      'list_literal_syntax_test_04_multi': notyetstrong,
      'list_literal_syntax_test_05_multi': notyetstrong,
      'list_literal_syntax_test_06_multi': notyetstrong,
      'list_literal_syntax_test_07_multi': notyetstrong,
      'list_literal_test': notyetstrong,
      'list_test': notyetstrong,
      'literal_unary_plus_test_01_multi': notyetstrong,
      'literal_unary_plus_test_02_multi': notyetstrong,
      'literal_unary_plus_test_03_multi': notyetstrong,
      'local_function2_test': notyetstrong,
      'local_function3_test': notyetstrong,
      'local_function_test': notyetstrong,
      'logical_expression3_test': notyetstrong,
      'malbounded_instantiation_test_01_multi': notyetstrong,
      'malbounded_instantiation_test_02_multi': notyetstrong,
      'malbounded_instantiation_test_03_multi': notyetstrong,
      'malbounded_redirecting_factory2_test_01_multi': notyetstrong,
      'malbounded_redirecting_factory2_test_02_multi': notyetstrong,
      'malbounded_redirecting_factory2_test_03_multi': notyetstrong,
      'malbounded_redirecting_factory2_test_04_multi': notyetstrong,
      'malbounded_redirecting_factory2_test_none_multi': notyetstrong,
      'malbounded_redirecting_factory_test_01_multi': notyetstrong,
      'malbounded_redirecting_factory_test_02_multi': notyetstrong,
      'malbounded_redirecting_factory_test_03_multi': notyetstrong,
      'malbounded_redirecting_factory_test_04_multi': notyetstrong,
      'malbounded_redirecting_factory_test_none_multi': notyetstrong,
      'malbounded_type_cast2_test': notyetstrong,
      'malbounded_type_cast_test': notyetstrong,
      'malbounded_type_literal_test': notyetstrong,
      'malbounded_type_test2_test': notyetstrong,
      'malbounded_type_test_test_01_multi': notyetstrong,
      'malbounded_type_test_test_02_multi': notyetstrong,
      'malbounded_type_test_test_03_multi': notyetstrong,
      'malbounded_type_test_test_04_multi': notyetstrong,
      'malformed2_test_00_multi': notyetstrong,
      'malformed2_test_01_multi': notyetstrong,
      'malformed2_test_none_multi': notyetstrong,
      'malformed_bound_test_01_multi': notyetstrong,
      'malformed_inheritance_test_01_multi': notyetstrong,
      'malformed_inheritance_test_02_multi': notyetstrong,
      'malformed_inheritance_test_03_multi': notyetstrong,
      'malformed_inheritance_test_04_multi': notyetstrong,
      'malformed_inheritance_test_05_multi': notyetstrong,
      'malformed_inheritance_test_06_multi': notyetstrong,
      'malformed_inheritance_test_07_multi': notyetstrong,
      'malformed_inheritance_test_08_multi': notyetstrong,
      'malformed_inheritance_test_09_multi': notyetstrong,
      'malformed_inheritance_test_10_multi': notyetstrong,
      'malformed_inheritance_test_11_multi': notyetstrong,
      'malformed_inheritance_test_12_multi': notyetstrong,
      'malformed_test_01_multi': notyetstrong,
      'malformed_test_02_multi': notyetstrong,
      'malformed_test_03_multi': notyetstrong,
      'malformed_test_04_multi': notyetstrong,
      'malformed_test_06_multi': notyetstrong,
      'malformed_test_none_multi': notyetstrong,
      'malformed_type_test': notyetstrong,
      'many_overridden_no_such_method_test': notyetstrong,
      'map_literal1_test_01_multi': notyetstrong,
      'map_literal3_test': notyetstrong,
      'map_literal4_test': notyetstrong,
      'map_literal6_test': notyetstrong,
      'map_literal8_test': notyetstrong,
      'metadata_test': notyetstrong,
      'method_override2_test_00_multi': notyetstrong,
      'method_override2_test_01_multi': notyetstrong,
      'method_override2_test_02_multi': notyetstrong,
      'method_override2_test_03_multi': notyetstrong,
      'method_override3_test_00_multi': notyetstrong,
      'method_override3_test_01_multi': notyetstrong,
      'method_override3_test_02_multi': notyetstrong,
      'method_override4_test': notyetstrong,
      'method_override5_test': notyetstrong,
      'method_override6_test': notyetstrong,
      'method_override7_test_00_multi': notyetstrong,
      'method_override7_test_01_multi': notyetstrong,
      'method_override7_test_02_multi': notyetstrong,
      'method_override8_test_00_multi': notyetstrong,
      'method_override8_test_01_multi': notyetstrong,
      'method_override8_test_03_multi': notyetstrong,
      'method_override_test': notyetstrong,
      'minify_closure_variable_collision_test': notyetstrong,
      'missing_const_constructor_test_02_multi': notyetstrong,
      'missing_const_constructor_test_03_multi': notyetstrong,
      'missing_const_constructor_test_04_multi': notyetstrong,
      'missing_const_constructor_test_05_multi': notyetstrong,
      'missing_const_constructor_test_06_multi': notyetstrong,
      'missing_part_of_tag_test_01_multi': notyetstrong,
      'mixin_black_listed_test_01_multi': notyetstrong,
      'mixin_black_listed_test_02_multi': notyetstrong,
      'mixin_black_listed_test_03_multi': notyetstrong,
      'mixin_black_listed_test_04_multi': notyetstrong,
      'mixin_black_listed_test_05_multi': notyetstrong,
      'mixin_black_listed_test_06_multi': notyetstrong,
      'mixin_black_listed_test_07_multi': notyetstrong,
      'mixin_black_listed_test_08_multi': notyetstrong,
      'mixin_cyclic_test_01_multi': notyetstrong,
      'mixin_cyclic_test_02_multi': notyetstrong,
      'mixin_extends_field_test': notyetstrong,
      'mixin_extends_method_test': notyetstrong,
      'mixin_field_test': notyetstrong,
      'mixin_forwarding_constructor4_test_01_multi': notyetstrong,
      'mixin_forwarding_constructor4_test_02_multi': notyetstrong,
      'mixin_forwarding_constructor4_test_03_multi': notyetstrong,
      'mixin_illegal_constructor_test_01_multi': notyetstrong,
      'mixin_illegal_constructor_test_02_multi': notyetstrong,
      'mixin_illegal_constructor_test_03_multi': notyetstrong,
      'mixin_illegal_constructor_test_04_multi': notyetstrong,
      'mixin_illegal_constructor_test_05_multi': notyetstrong,
      'mixin_illegal_constructor_test_06_multi': notyetstrong,
      'mixin_illegal_constructor_test_07_multi': notyetstrong,
      'mixin_illegal_constructor_test_08_multi': notyetstrong,
      'mixin_illegal_constructor_test_09_multi': notyetstrong,
      'mixin_illegal_constructor_test_10_multi': notyetstrong,
      'mixin_illegal_constructor_test_11_multi': notyetstrong,
      'mixin_illegal_constructor_test_12_multi': notyetstrong,
      'mixin_illegal_constructor_test_13_multi': notyetstrong,
      'mixin_illegal_constructor_test_14_multi': notyetstrong,
      'mixin_illegal_constructor_test_15_multi': notyetstrong,
      'mixin_illegal_constructor_test_16_multi': notyetstrong,
      'mixin_illegal_cycles_test_01_multi': notyetstrong,
      'mixin_illegal_cycles_test_02_multi': notyetstrong,
      'mixin_illegal_cycles_test_03_multi': notyetstrong,
      'mixin_illegal_cycles_test_04_multi': notyetstrong,
      'mixin_illegal_cycles_test_05_multi': notyetstrong,
      'mixin_illegal_cycles_test_06_multi': notyetstrong,
      'mixin_illegal_object_test_01_multi': notyetstrong,
      'mixin_illegal_object_test_02_multi': notyetstrong,
      'mixin_illegal_static_access_test': notyetstrong,
      'mixin_illegal_super_use_test_01_multi': notyetstrong,
      'mixin_illegal_super_use_test_02_multi': notyetstrong,
      'mixin_illegal_super_use_test_03_multi': notyetstrong,
      'mixin_illegal_super_use_test_04_multi': notyetstrong,
      'mixin_illegal_super_use_test_05_multi': notyetstrong,
      'mixin_illegal_super_use_test_06_multi': notyetstrong,
      'mixin_illegal_super_use_test_07_multi': notyetstrong,
      'mixin_illegal_super_use_test_08_multi': notyetstrong,
      'mixin_illegal_super_use_test_09_multi': notyetstrong,
      'mixin_illegal_super_use_test_10_multi': notyetstrong,
      'mixin_illegal_super_use_test_11_multi': notyetstrong,
      'mixin_illegal_superclass_test_01_multi': notyetstrong,
      'mixin_illegal_superclass_test_02_multi': notyetstrong,
      'mixin_illegal_superclass_test_03_multi': notyetstrong,
      'mixin_illegal_superclass_test_04_multi': notyetstrong,
      'mixin_illegal_superclass_test_05_multi': notyetstrong,
      'mixin_illegal_superclass_test_06_multi': notyetstrong,
      'mixin_illegal_superclass_test_07_multi': notyetstrong,
      'mixin_illegal_superclass_test_08_multi': notyetstrong,
      'mixin_illegal_superclass_test_09_multi': notyetstrong,
      'mixin_illegal_superclass_test_10_multi': notyetstrong,
      'mixin_illegal_superclass_test_11_multi': notyetstrong,
      'mixin_illegal_superclass_test_12_multi': notyetstrong,
      'mixin_illegal_superclass_test_13_multi': notyetstrong,
      'mixin_illegal_superclass_test_14_multi': notyetstrong,
      'mixin_illegal_superclass_test_15_multi': notyetstrong,
      'mixin_illegal_superclass_test_16_multi': notyetstrong,
      'mixin_illegal_superclass_test_17_multi': notyetstrong,
      'mixin_illegal_superclass_test_18_multi': notyetstrong,
      'mixin_illegal_superclass_test_19_multi': notyetstrong,
      'mixin_illegal_superclass_test_20_multi': notyetstrong,
      'mixin_illegal_superclass_test_21_multi': notyetstrong,
      'mixin_illegal_superclass_test_22_multi': notyetstrong,
      'mixin_illegal_superclass_test_23_multi': notyetstrong,
      'mixin_illegal_superclass_test_24_multi': notyetstrong,
      'mixin_illegal_superclass_test_25_multi': notyetstrong,
      'mixin_illegal_superclass_test_26_multi': notyetstrong,
      'mixin_illegal_superclass_test_27_multi': notyetstrong,
      'mixin_illegal_superclass_test_28_multi': notyetstrong,
      'mixin_illegal_superclass_test_29_multi': notyetstrong,
      'mixin_illegal_superclass_test_30_multi': notyetstrong,
      'mixin_illegal_syntax_test_01_multi': notyetstrong,
      'mixin_illegal_syntax_test_02_multi': notyetstrong,
      'mixin_illegal_syntax_test_03_multi': notyetstrong,
      'mixin_illegal_syntax_test_04_multi': notyetstrong,
      'mixin_illegal_syntax_test_05_multi': notyetstrong,
      'mixin_illegal_syntax_test_06_multi': notyetstrong,
      'mixin_illegal_syntax_test_07_multi': notyetstrong,
      'mixin_illegal_syntax_test_08_multi': notyetstrong,
      'mixin_illegal_syntax_test_09_multi': notyetstrong,
      'mixin_illegal_syntax_test_10_multi': notyetstrong,
      'mixin_illegal_syntax_test_11_multi': notyetstrong,
      'mixin_illegal_syntax_test_12_multi': notyetstrong,
      'mixin_illegal_syntax_test_13_multi': notyetstrong,
      'mixin_illegal_syntax_test_14_multi': notyetstrong,
      'mixin_illegal_syntax_test_none_multi': notyetstrong,
      'mixin_invalid_bound2_test_01_multi': notyetstrong,
      'mixin_invalid_bound2_test_02_multi': notyetstrong,
      'mixin_invalid_bound2_test_03_multi': notyetstrong,
      'mixin_invalid_bound2_test_04_multi': notyetstrong,
      'mixin_invalid_bound2_test_05_multi': notyetstrong,
      'mixin_invalid_bound2_test_06_multi': notyetstrong,
      'mixin_invalid_bound2_test_07_multi': notyetstrong,
      'mixin_invalid_bound2_test_08_multi': notyetstrong,
      'mixin_invalid_bound2_test_09_multi': notyetstrong,
      'mixin_invalid_bound2_test_10_multi': notyetstrong,
      'mixin_invalid_bound2_test_11_multi': notyetstrong,
      'mixin_invalid_bound2_test_12_multi': notyetstrong,
      'mixin_invalid_bound2_test_13_multi': notyetstrong,
      'mixin_invalid_bound2_test_14_multi': notyetstrong,
      'mixin_invalid_bound2_test_none_multi': notyetstrong,
      'mixin_invalid_bound_test_01_multi': notyetstrong,
      'mixin_invalid_bound_test_02_multi': notyetstrong,
      'mixin_invalid_bound_test_03_multi': notyetstrong,
      'mixin_invalid_bound_test_04_multi': notyetstrong,
      'mixin_invalid_bound_test_05_multi': notyetstrong,
      'mixin_invalid_bound_test_06_multi': notyetstrong,
      'mixin_invalid_bound_test_07_multi': notyetstrong,
      'mixin_invalid_bound_test_08_multi': notyetstrong,
      'mixin_invalid_bound_test_09_multi': notyetstrong,
      'mixin_invalid_bound_test_10_multi': notyetstrong,
      'mixin_invalid_bound_test_none_multi': notyetstrong,
      'mixin_invalid_inheritance1_test_01_multi': notyetstrong,
      'mixin_invalid_inheritance1_test_02_multi': notyetstrong,
      'mixin_invalid_inheritance1_test_03_multi': notyetstrong,
      'mixin_invalid_inheritance2_test_01_multi': notyetstrong,
      'mixin_invalid_inheritance2_test_02_multi': notyetstrong,
      'mixin_invalid_inheritance2_test_03_multi': notyetstrong,
      'mixin_lib_extends_field_test': notyetstrong,
      'mixin_lib_extends_method_test': notyetstrong,
      'mixin_method_test': notyetstrong,
      'mixin_super_bound2_test_01_multi': notyetstrong,
      'mixin_super_bound2_test_none_multi': notyetstrong,
      'mixin_super_bound_test': notyetstrong,
      'mixin_super_constructor2_test': notyetstrong,
      'mixin_super_constructor_default_test': notyetstrong,
      'mixin_super_constructor_named_test_01_multi': notyetstrong,
      'mixin_super_constructor_named_test_none_multi': notyetstrong,
      'mixin_super_constructor_positionals_test_01_multi': notyetstrong,
      'mixin_super_constructor_positionals_test_none_multi': notyetstrong,
      'mixin_super_constructor_test': notyetstrong,
      'mixin_super_test': notyetstrong,
      'mixin_type_parameter4_test': notyetstrong,
      'mixin_type_parameters_errors_test_01_multi': notyetstrong,
      'mixin_type_parameters_errors_test_02_multi': notyetstrong,
      'mixin_type_parameters_errors_test_03_multi': notyetstrong,
      'mixin_type_parameters_errors_test_04_multi': notyetstrong,
      'mixin_type_parameters_errors_test_05_multi': notyetstrong,
      'mixin_type_parameters_mixin_extends_test': notyetstrong,
      'mixin_type_parameters_mixin_test': notyetstrong,
      'mixin_type_parameters_simple_test': notyetstrong,
      'mixin_type_parameters_super_extends_test': notyetstrong,
      'mixin_type_parameters_super_test': notyetstrong,
      'mixin_with_two_implicit_constructors_test': notyetstrong,
      'multi_pass2_test': notyetstrong,
      'multi_pass_test': notyetstrong,
      'multiline_newline_test_01_multi': notyetstrong,
      'multiline_newline_test_02_multi': notyetstrong,
      'multiline_newline_test_03_multi': notyetstrong,
      'named_constructor_test_01_multi': notyetstrong,
      'named_constructor_test_02_multi': notyetstrong,
      'named_constructor_test_03_multi': notyetstrong,
      'named_constructor_test_04_multi': notyetstrong,
      'named_constructor_test_05_multi': notyetstrong,
      'named_constructor_test_06_multi': notyetstrong,
      'named_constructor_test_07_multi': notyetstrong,
      'named_constructor_test_08_multi': notyetstrong,
      'named_constructor_test_09_multi': notyetstrong,
      'named_constructor_test_10_multi': notyetstrong,
      'named_parameters2_test': notyetstrong,
      'named_parameters3_test': notyetstrong,
      'named_parameters4_test': notyetstrong,
      'named_parameters_aggregated_test_01_multi': notyetstrong,
      'named_parameters_aggregated_test_02_multi': notyetstrong,
      'named_parameters_aggregated_test_03_multi': notyetstrong,
      'named_parameters_aggregated_test_04_multi': notyetstrong,
      'named_parameters_aggregated_test_05_multi': notyetstrong,
      'named_parameters_test_01_multi': notyetstrong,
      'named_parameters_test_02_multi': notyetstrong,
      'named_parameters_test_03_multi': notyetstrong,
      'named_parameters_test_04_multi': notyetstrong,
      'named_parameters_test_05_multi': notyetstrong,
      'named_parameters_test_06_multi': notyetstrong,
      'named_parameters_test_07_multi': notyetstrong,
      'named_parameters_test_08_multi': notyetstrong,
      'named_parameters_test_09_multi': notyetstrong,
      'named_parameters_test_10_multi': notyetstrong,
      'named_parameters_type_test_01_multi': notyetstrong,
      'named_parameters_type_test_02_multi': notyetstrong,
      'named_parameters_type_test_03_multi': notyetstrong,
      'naming3_test': notyetstrong,
      'naming_test': notyetstrong,
      'new_expression_type_args_test_00_multi': notyetstrong,
      'new_expression_type_args_test_01_multi': notyetstrong,
      'new_expression_type_args_test_02_multi': notyetstrong,
      'new_prefix_test_01_multi': notyetstrong,
      'no_such_constructor2_test': notyetstrong,
      'no_such_constructor_test_01_multi': notyetstrong,
      'no_such_method2_test': notyetstrong,
      'no_such_method_dispatcher_test': notyetstrong,
      'no_such_method_test': notyetstrong,
      'non_parameterized_factory2_test': notyetstrong,
      'non_parameterized_factory_test': notyetstrong,
      'not_enough_positional_arguments_test_00_multi': notyetstrong,
      'not_enough_positional_arguments_test_01_multi': notyetstrong,
      'not_enough_positional_arguments_test_02_multi': notyetstrong,
      'not_enough_positional_arguments_test_03_multi': notyetstrong,
      'not_enough_positional_arguments_test_05_multi': notyetstrong,
      'not_enough_positional_arguments_test_06_multi': notyetstrong,
      'not_enough_positional_arguments_test_07_multi': notyetstrong,
      'null_test_01_multi': notyetstrong,
      'null_test_02_multi': notyetstrong,
      'null_test_03_multi': notyetstrong,
      'null_test_none_multi': notyetstrong,
      'number_identifier_test_01_multi': notyetstrong,
      'number_identifier_test_02_multi': notyetstrong,
      'number_identifier_test_03_multi': notyetstrong,
      'number_identifier_test_04_multi': notyetstrong,
      'number_identifier_test_06_multi': notyetstrong,
      'number_identifier_test_07_multi': notyetstrong,
      'number_identifier_test_08_multi': notyetstrong,
      'number_identifier_test_09_multi': notyetstrong,
      'number_identifier_test_10_multi': notyetstrong,
      'number_identifier_test_11_multi': notyetstrong,
      'number_identity_test': notyetstrong,
      'on_catch_malformed_type_test': notyetstrong,
      'operator5_test': notyetstrong,
      'operator_equals_test': notyetstrong,
      'operator_test': notyetstrong,
      'optimized_constant_array_string_access_test': notyetstrong,
      'optional_named_parameters_test_01_multi': notyetstrong,
      'optional_named_parameters_test_02_multi': notyetstrong,
      'optional_named_parameters_test_03_multi': notyetstrong,
      'optional_named_parameters_test_04_multi': notyetstrong,
      'optional_named_parameters_test_05_multi': notyetstrong,
      'optional_named_parameters_test_06_multi': notyetstrong,
      'optional_named_parameters_test_07_multi': notyetstrong,
      'optional_named_parameters_test_08_multi': notyetstrong,
      'optional_named_parameters_test_09_multi': notyetstrong,
      'overridden_no_such_method_test': notyetstrong,
      'override_field_test_01_multi': notyetstrong,
      'override_field_test_02_multi': notyetstrong,
      'override_inheritance_abstract_test_02_multi': notyetstrong,
      'override_inheritance_abstract_test_03_multi': notyetstrong,
      'override_inheritance_abstract_test_04_multi': notyetstrong,
      'override_inheritance_abstract_test_07_multi': notyetstrong,
      'override_inheritance_abstract_test_08_multi': notyetstrong,
      'override_inheritance_abstract_test_09_multi': notyetstrong,
      'override_inheritance_abstract_test_10_multi': notyetstrong,
      'override_inheritance_abstract_test_11_multi': notyetstrong,
      'override_inheritance_abstract_test_12_multi': notyetstrong,
      'override_inheritance_abstract_test_13_multi': notyetstrong,
      'override_inheritance_abstract_test_14_multi': notyetstrong,
      'override_inheritance_abstract_test_17_multi': notyetstrong,
      'override_inheritance_abstract_test_19_multi': notyetstrong,
      'override_inheritance_abstract_test_20_multi': notyetstrong,
      'override_inheritance_abstract_test_21_multi': notyetstrong,
      'override_inheritance_abstract_test_22_multi': notyetstrong,
      'override_inheritance_abstract_test_23_multi': notyetstrong,
      'override_inheritance_abstract_test_24_multi': notyetstrong,
      'override_inheritance_abstract_test_25_multi': notyetstrong,
      'override_inheritance_abstract_test_26_multi': notyetstrong,
      'override_inheritance_field_test_04_multi': notyetstrong,
      'override_inheritance_field_test_05_multi': notyetstrong,
      'override_inheritance_field_test_06_multi': notyetstrong,
      'override_inheritance_field_test_07_multi': notyetstrong,
      'override_inheritance_field_test_08_multi': notyetstrong,
      'override_inheritance_field_test_09_multi': notyetstrong,
      'override_inheritance_field_test_10_multi': notyetstrong,
      'override_inheritance_field_test_11_multi': notyetstrong,
      'override_inheritance_field_test_26_multi': notyetstrong,
      'override_inheritance_field_test_28_multi': notyetstrong,
      'override_inheritance_field_test_29_multi': notyetstrong,
      'override_inheritance_field_test_30_multi': notyetstrong,
      'override_inheritance_field_test_31_multi': notyetstrong,
      'override_inheritance_field_test_32_multi': notyetstrong,
      'override_inheritance_field_test_33_multi': notyetstrong,
      'override_inheritance_field_test_33a_multi': notyetstrong,
      'override_inheritance_field_test_34_multi': notyetstrong,
      'override_inheritance_field_test_41_multi': notyetstrong,
      'override_inheritance_field_test_42_multi': notyetstrong,
      'override_inheritance_field_test_43_multi': notyetstrong,
      'override_inheritance_field_test_44_multi': notyetstrong,
      'override_inheritance_field_test_45_multi': notyetstrong,
      'override_inheritance_field_test_46_multi': notyetstrong,
      'override_inheritance_field_test_47_multi': notyetstrong,
      'override_inheritance_field_test_48_multi': notyetstrong,
      'override_inheritance_field_test_49_multi': notyetstrong,
      'override_inheritance_field_test_50_multi': notyetstrong,
      'override_inheritance_field_test_53_multi': notyetstrong,
      'override_inheritance_field_test_54_multi': notyetstrong,
      'override_inheritance_generic_test_02_multi': notyetstrong,
      'override_inheritance_generic_test_04_multi': notyetstrong,
      'override_inheritance_generic_test_06_multi': notyetstrong,
      'override_inheritance_generic_test_07_multi': notyetstrong,
      'override_inheritance_generic_test_08_multi': notyetstrong,
      'override_inheritance_generic_test_09_multi': notyetstrong,
      'override_inheritance_generic_test_10_multi': notyetstrong,
      'override_inheritance_method_test_04_multi': notyetstrong,
      'override_inheritance_method_test_05_multi': notyetstrong,
      'override_inheritance_method_test_06_multi': notyetstrong,
      'override_inheritance_method_test_11_multi': notyetstrong,
      'override_inheritance_method_test_12_multi': notyetstrong,
      'override_inheritance_method_test_13_multi': notyetstrong,
      'override_inheritance_method_test_14_multi': notyetstrong,
      'override_inheritance_method_test_19_multi': notyetstrong,
      'override_inheritance_method_test_20_multi': notyetstrong,
      'override_inheritance_method_test_21_multi': notyetstrong,
      'override_inheritance_method_test_27_multi': notyetstrong,
      'override_inheritance_method_test_28_multi': notyetstrong,
      'override_inheritance_method_test_29_multi': notyetstrong,
      'override_inheritance_method_test_30_multi': notyetstrong,
      'override_inheritance_method_test_31_multi': notyetstrong,
      'override_inheritance_method_test_32_multi': notyetstrong,
      'override_inheritance_method_test_33_multi': notyetstrong,
      'override_inheritance_mixed_test_01_multi': notyetstrong,
      'override_inheritance_mixed_test_02_multi': notyetstrong,
      'override_inheritance_mixed_test_03_multi': notyetstrong,
      'override_inheritance_mixed_test_04_multi': notyetstrong,
      'override_inheritance_mixed_test_06_multi': notyetstrong,
      'override_inheritance_mixed_test_07_multi': notyetstrong,
      'override_inheritance_mixed_test_08_multi': notyetstrong,
      'override_inheritance_mixed_test_09_multi': notyetstrong,
      'override_inheritance_no_such_method_test_01_multi': notyetstrong,
      'override_inheritance_no_such_method_test_02_multi': notyetstrong,
      'override_inheritance_no_such_method_test_06_multi': notyetstrong,
      'override_inheritance_no_such_method_test_07_multi': notyetstrong,
      'override_inheritance_no_such_method_test_09_multi': notyetstrong,
      'override_inheritance_no_such_method_test_10_multi': notyetstrong,
      'override_inheritance_no_such_method_test_12_multi': notyetstrong,
      'override_method_with_field_test_01_multi': notyetstrong,
      'override_method_with_field_test_02_multi': notyetstrong,
      'parameter_default_test_01_multi': notyetstrong,
      'parameter_default_test_02_multi': notyetstrong,
      'parameter_default_test_03_multi': notyetstrong,
      'parameter_default_test_04_multi': notyetstrong,
      'parameter_default_test_05_multi': notyetstrong,
      'parameter_default_test_06_multi': notyetstrong,
      'parameter_default_test_07_multi': notyetstrong,
      'parameter_default_test_08_multi': notyetstrong,
      'parameter_initializer_test': notyetstrong,
      'parser_quirks_test': notyetstrong,
      'part2_test': notyetstrong,
      'part_test': notyetstrong,
      'positional_parameters_type_test_01_multi': notyetstrong,
      'positional_parameters_type_test_02_multi': notyetstrong,
      'prefix14_test': notyetstrong,
      'prefix15_test': notyetstrong,
      'prefix16_test': notyetstrong,
      'prefix22_test': notyetstrong,
      'prefix23_test': notyetstrong,
      'prefix_assignment_test_01_multi': notyetstrong,
      'prefix_assignment_test_02_multi': notyetstrong,
      'prefix_identifier_reference_test_01_multi': notyetstrong,
      'prefix_identifier_reference_test_02_multi': notyetstrong,
      'prefix_identifier_reference_test_03_multi': notyetstrong,
      'prefix_identifier_reference_test_04_multi': notyetstrong,
      'prefix_identifier_reference_test_05_multi': notyetstrong,
      'prefix_unqualified_invocation_test_01_multi': notyetstrong,
      'prefix_unqualified_invocation_test_02_multi': notyetstrong,
      'private2_test': notyetstrong,
      'private3_test': notyetstrong,
      'private_access_test_01_multi': notyetstrong,
      'private_access_test_02_multi': notyetstrong,
      'private_access_test_03_multi': notyetstrong,
      'private_access_test_04_multi': notyetstrong,
      'private_access_test_05_multi': notyetstrong,
      'private_access_test_06_multi': notyetstrong,
      'private_mixin2_test': notyetstrong,
      'private_test': notyetstrong,
      'propagated_argument_type_check_test': notyetstrong,
      'property_field_override_test': notyetstrong,
      'proxy2_test_01_multi': notyetstrong,
      'proxy2_test_02_multi': notyetstrong,
      'proxy3_test_01_multi': notyetstrong,
      'proxy3_test_02_multi': notyetstrong,
      'proxy3_test_03_multi': notyetstrong,
      'proxy3_test_04_multi': notyetstrong,
      'proxy_test_01_multi': notyetstrong,
      'proxy_test_02_multi': notyetstrong,
      'proxy_test_05_multi': notyetstrong,
      'proxy_test_06_multi': notyetstrong,
      'redirecting_constructor_initializer_test': notyetstrong,
      'redirecting_factory_default_values_test_01_multi': notyetstrong,
      'redirecting_factory_default_values_test_02_multi': notyetstrong,
      'redirecting_factory_default_values_test_none_multi': notyetstrong,
      'redirecting_factory_incompatible_signature_test': notyetstrong,
      'redirecting_factory_infinite_steps_test_01_multi': notyetstrong,
      'redirecting_factory_infinite_steps_test_02_multi': notyetstrong,
      'redirecting_factory_long_test': notyetstrong,
      'redirecting_factory_malbounded_test_01_multi': notyetstrong,
      'redirecting_factory_malbounded_test_none_multi': notyetstrong,
      'ref_before_declaration_test_00_multi': notyetstrong,
      'ref_before_declaration_test_01_multi': notyetstrong,
      'ref_before_declaration_test_02_multi': notyetstrong,
      'ref_before_declaration_test_03_multi': notyetstrong,
      'ref_before_declaration_test_04_multi': notyetstrong,
      'ref_before_declaration_test_05_multi': notyetstrong,
      'ref_before_declaration_test_06_multi': notyetstrong,
      'ref_before_declaration_test_07_multi': notyetstrong,
      'ref_before_declaration_test_none_multi': notyetstrong,
      'regress_12561_test': notyetstrong,
      'regress_13494_test': notyetstrong,
      'regress_14348_test': notyetstrong,
      'regress_17382_test': notyetstrong,
      'regress_19413_test_01_multi': notyetstrong,
      'regress_19728_test': notyetstrong,
      'regress_20394_test_01_multi': notyetstrong,
      'regress_21793_test_01_multi': notyetstrong,
      'regress_21912_test_01_multi': notyetstrong,
      'regress_21912_test_02_multi': notyetstrong,
      'regress_22438_test': notyetstrong,
      'regress_22936_test_01_multi': notyetstrong,
      'regress_23038_test_01_multi': notyetstrong,
      'regress_23051_test_01_multi': notyetstrong,
      'regress_23408_test': notyetstrong,
      'return_type_test': notyetstrong,
      'rewrite_implicit_this_test_01_multi': notyetstrong,
      'scope_variable_test_01_multi': notyetstrong,
      'setter_no_getter_call_test_01_multi': notyetstrong,
      'setter_override2_test_00_multi': notyetstrong,
      'setter_override_test_00_multi': notyetstrong,
      'setter_override_test_01_multi': notyetstrong,
      'setter_override_test_02_multi': notyetstrong,
      'setter_override_test_03_multi': notyetstrong,
      'static_field1_test': notyetstrong,
      'static_field1a_test': notyetstrong,
      'static_field2_test': notyetstrong,
      'static_field2a_test': notyetstrong,
      'static_field3_test_01_multi': notyetstrong,
      'static_field3_test_02_multi': notyetstrong,
      'static_field3_test_03_multi': notyetstrong,
      'static_field3_test_04_multi': notyetstrong,
      'static_field_test_01_multi': notyetstrong,
      'static_field_test_02_multi': notyetstrong,
      'static_field_test_03_multi': notyetstrong,
      'static_field_test_04_multi': notyetstrong,
      'static_final_field2_test_01_multi': notyetstrong,
      'static_final_field2_test_02_multi': notyetstrong,
      'static_getter_no_setter1_test_01_multi': notyetstrong,
      'static_getter_no_setter2_test_01_multi': notyetstrong,
      'static_getter_no_setter3_test_01_multi': notyetstrong,
      'static_initializer_type_error_test': notyetstrong,
      'static_parameter_test_01_multi': notyetstrong,
      'static_parameter_test_02_multi': notyetstrong,
      'static_parameter_test_03_multi': notyetstrong,
      'static_parameter_test_04_multi': notyetstrong,
      'static_parameter_test_05_multi': notyetstrong,
      'static_parameter_test_06_multi': notyetstrong,
      'static_parameter_test_07_multi': notyetstrong,
      'static_parameter_test_08_multi': notyetstrong,
      'static_parameter_test_09_multi': notyetstrong,
      'static_parameter_test_10_multi': notyetstrong,
      'static_parameter_test_11_multi': notyetstrong,
      'static_parameter_test_12_multi': notyetstrong,
      'static_setter_get_test_01_multi': notyetstrong,
      'static_top_level_test_00_multi': notyetstrong,
      'static_top_level_test_01_multi': notyetstrong,
      'static_top_level_test_02_multi': notyetstrong,
      'static_top_level_test_03_multi': notyetstrong,
      'static_top_level_test_04_multi': notyetstrong,
      'static_top_level_test_05_multi': notyetstrong,
      'static_top_level_test_06_multi': notyetstrong,
      'static_top_level_test_07_multi': notyetstrong,
      'string_interpolate_test': notyetstrong,
      'string_interpolation9_test_10_multi': notyetstrong,
      'string_interpolation9_test_11_multi': notyetstrong,
      'string_interpolation9_test_12_multi': notyetstrong,
      'string_interpolation9_test_13_multi': notyetstrong,
      'string_interpolation9_test_14_multi': notyetstrong,
      'string_interpolation9_test_15_multi': notyetstrong,
      'string_interpolation9_test_16_multi': notyetstrong,
      'string_interpolation9_test_17_multi': notyetstrong,
      'string_interpolation9_test_18_multi': notyetstrong,
      'string_interpolation9_test_19_multi': notyetstrong,
      'string_interpolation9_test_1_multi': notyetstrong,
      'string_interpolation9_test_20_multi': notyetstrong,
      'string_interpolation9_test_2_multi': notyetstrong,
      'string_interpolation9_test_3_multi': notyetstrong,
      'string_interpolation9_test_4_multi': notyetstrong,
      'string_interpolation9_test_5_multi': notyetstrong,
      'string_interpolation9_test_6_multi': notyetstrong,
      'string_interpolation9_test_7_multi': notyetstrong,
      'string_interpolation9_test_8_multi': notyetstrong,
      'string_interpolation9_test_9_multi': notyetstrong,
      'string_interpolation_and_buffer_test': notyetstrong,
      'string_interpolation_test_01_multi': notyetstrong,
      'string_no_operator_test': notyetstrong,
      'string_split_test': notyetstrong,
      'string_supertype_checked_test': notyetstrong,
      'string_test': notyetstrong,
      'substring_test_01_multi': notyetstrong,
      'super_assign_test': notyetstrong,
      'super_bound_closure_test_01_multi': notyetstrong,
      'super_bound_closure_test_none_multi': notyetstrong,
      'super_call3_test_01_multi': notyetstrong,
      'super_call3_test_02_multi': notyetstrong,
      'super_call4_test': notyetstrong,
      'super_conditional_operator_test_01_multi': notyetstrong,
      'super_conditional_operator_test_02_multi': notyetstrong,
      'super_conditional_operator_test_03_multi': notyetstrong,
      'super_conditional_operator_test_04_multi': notyetstrong,
      'super_conditional_operator_test_05_multi': notyetstrong,
      'super_conditional_operator_test_06_multi': notyetstrong,
      'super_conditional_operator_test_07_multi': notyetstrong,
      'super_conditional_operator_test_08_multi': notyetstrong,
      'super_conditional_operator_test_09_multi': notyetstrong,
      'super_conditional_operator_test_10_multi': notyetstrong,
      'super_conditional_operator_test_11_multi': notyetstrong,
      'super_conditional_operator_test_12_multi': notyetstrong,
      'super_conditional_operator_test_13_multi': notyetstrong,
      'super_conditional_operator_test_14_multi': notyetstrong,
      'super_conditional_operator_test_15_multi': notyetstrong,
      'super_conditional_operator_test_16_multi': notyetstrong,
      'super_conditional_operator_test_17_multi': notyetstrong,
      'super_conditional_operator_test_18_multi': notyetstrong,
      'super_field_access_test': notyetstrong,
      'super_first_constructor_test': notyetstrong,
      'super_getter_setter_test': notyetstrong,
      'super_operator_index5_test': notyetstrong,
      'super_operator_index6_test': notyetstrong,
      'super_operator_index7_test': notyetstrong,
      'super_operator_index8_test': notyetstrong,
      'super_operator_index_test_01_multi': notyetstrong,
      'super_operator_index_test_02_multi': notyetstrong,
      'super_operator_index_test_03_multi': notyetstrong,
      'super_operator_index_test_04_multi': notyetstrong,
      'super_operator_index_test_05_multi': notyetstrong,
      'super_operator_index_test_06_multi': notyetstrong,
      'super_operator_index_test_07_multi': notyetstrong,
      'super_operator_test': notyetstrong,
      'super_test': notyetstrong,
      'switch6_test': notyetstrong,
      'switch_bad_case_test_01_multi': notyetstrong,
      'switch_bad_case_test_02_multi': notyetstrong,
      'switch_case_test_00_multi': notyetstrong,
      'switch_case_test_01_multi': notyetstrong,
      'switch_case_test_02_multi': notyetstrong,
      'switch_case_test_none_multi': notyetstrong,
      'switch_fallthru_test': notyetstrong,
      'symbol_conflict_test': notyetstrong,
      'symbol_literal_test_01_multi': notyetstrong,
      'sync_generator1_test_01_multi': notyetstrong,
      'sync_generator2_test_01_multi': notyetstrong,
      'sync_generator2_test_02_multi': notyetstrong,
      'sync_generator2_test_03_multi': notyetstrong,
      'sync_generator2_test_04_multi': notyetstrong,
      'sync_generator2_test_05_multi': notyetstrong,
      'sync_generator2_test_06_multi': notyetstrong,
      'sync_generator2_test_07_multi': notyetstrong,
      'sync_generator2_test_08_multi': notyetstrong,
      'sync_generator2_test_09_multi': notyetstrong,
      'sync_generator2_test_10_multi': notyetstrong,
      'sync_generator2_test_11_multi': notyetstrong,
      'sync_generator2_test_20_multi': notyetstrong,
      'sync_generator2_test_30_multi': notyetstrong,
      'sync_generator2_test_40_multi': notyetstrong,
      'sync_generator2_test_41_multi': notyetstrong,
      'sync_generator2_test_50_multi': notyetstrong,
      'sync_generator2_test_51_multi': notyetstrong,
      'sync_generator2_test_52_multi': notyetstrong,
      'syntax_test_01_multi': notyetstrong,
      'syntax_test_02_multi': notyetstrong,
      'syntax_test_03_multi': notyetstrong,
      'syntax_test_04_multi': notyetstrong,
      'syntax_test_05_multi': notyetstrong,
      'syntax_test_06_multi': notyetstrong,
      'syntax_test_07_multi': notyetstrong,
      'syntax_test_08_multi': notyetstrong,
      'syntax_test_09_multi': notyetstrong,
      'syntax_test_10_multi': notyetstrong,
      'syntax_test_11_multi': notyetstrong,
      'syntax_test_12_multi': notyetstrong,
      'syntax_test_13_multi': notyetstrong,
      'syntax_test_14_multi': notyetstrong,
      'syntax_test_15_multi': notyetstrong,
      'syntax_test_16_multi': notyetstrong,
      'syntax_test_17_multi': notyetstrong,
      'syntax_test_18_multi': notyetstrong,
      'syntax_test_19_multi': notyetstrong,
      'syntax_test_20_multi': notyetstrong,
      'syntax_test_21_multi': notyetstrong,
      'syntax_test_22_multi': notyetstrong,
      'syntax_test_23_multi': notyetstrong,
      'syntax_test_24_multi': notyetstrong,
      'syntax_test_25_multi': notyetstrong,
      'syntax_test_26_multi': notyetstrong,
      'syntax_test_27_multi': notyetstrong,
      'syntax_test_28_multi': notyetstrong,
      'syntax_test_29_multi': notyetstrong,
      'syntax_test_30_multi': notyetstrong,
      'syntax_test_31_multi': notyetstrong,
      'syntax_test_32_multi': notyetstrong,
      'syntax_test_33_multi': notyetstrong,
      'syntax_test_34_multi': notyetstrong,
      'syntax_test_35_multi': notyetstrong,
      'syntax_test_36_multi': notyetstrong,
      'syntax_test_37_multi': notyetstrong,
      'syntax_test_38_multi': notyetstrong,
      'syntax_test_39_multi': notyetstrong,
      'syntax_test_40_multi': notyetstrong,
      'syntax_test_41_multi': notyetstrong,
      'syntax_test_42_multi': notyetstrong,
      'syntax_test_43_multi': notyetstrong,
      'syntax_test_44_multi': notyetstrong,
      'syntax_test_45_multi': notyetstrong,
      'syntax_test_46_multi': notyetstrong,
      'syntax_test_47_multi': notyetstrong,
      'syntax_test_48_multi': notyetstrong,
      'syntax_test_49_multi': notyetstrong,
      'syntax_test_50_multi': notyetstrong,
      'syntax_test_51_multi': notyetstrong,
      'syntax_test_52_multi': notyetstrong,
      'syntax_test_53_multi': notyetstrong,
      'syntax_test_54_multi': notyetstrong,
      'syntax_test_55_multi': notyetstrong,
      'syntax_test_56_multi': notyetstrong,
      'syntax_test_57_multi': notyetstrong,
      'syntax_test_58_multi': notyetstrong,
      'syntax_test_59_multi': notyetstrong,
      'syntax_test_60_multi': notyetstrong,
      'syntax_test_61_multi': notyetstrong,
      'syntax_test_62_multi': notyetstrong,
      'syntax_test_63_multi': notyetstrong,
      'syntax_test_64_multi': notyetstrong,
      'syntax_test_65_multi': notyetstrong,
      'syntax_test_none_multi': notyetstrong,
      'tearoff_basic_test': notyetstrong,
      'tearoff_constructor_basic_test': notyetstrong,
      'third_test': notyetstrong,
      'this_conditional_operator_test_01_multi': notyetstrong,
      'this_test_01_multi': notyetstrong,
      'this_test_02_multi': notyetstrong,
      'this_test_03_multi': notyetstrong,
      'this_test_04_multi': notyetstrong,
      'this_test_05_multi': notyetstrong,
      'this_test_06_multi': notyetstrong,
      'this_test_07_multi': notyetstrong,
      'this_test_08_multi': notyetstrong,
      'throw_expr_test': notyetstrong,
      'top_level_entry_test': notyetstrong,
      'top_level_getter_no_setter1_test_01_multi': notyetstrong,
      'top_level_getter_no_setter2_test_01_multi': notyetstrong,
      'top_level_multiple_files_test': notyetstrong,
      'toplevel_collision1_test_00_multi': notyetstrong,
      'toplevel_collision1_test_01_multi': notyetstrong,
      'toplevel_collision1_test_02_multi': notyetstrong,
      'toplevel_collision2_test_00_multi': notyetstrong,
      'toplevel_collision2_test_01_multi': notyetstrong,
      'transitive_private_library_access_test': notyetstrong,
      'try_catch_on_syntax_test_02_multi': notyetstrong,
      'try_catch_on_syntax_test_03_multi': notyetstrong,
      'try_catch_on_syntax_test_04_multi': notyetstrong,
      'try_catch_on_syntax_test_05_multi': notyetstrong,
      'try_catch_on_syntax_test_06_multi': notyetstrong,
      'try_catch_on_syntax_test_07_multi': notyetstrong,
      'try_catch_syntax_test_01_multi': notyetstrong,
      'try_catch_syntax_test_02_multi': notyetstrong,
      'try_catch_syntax_test_03_multi': notyetstrong,
      'try_catch_syntax_test_04_multi': notyetstrong,
      'try_catch_syntax_test_05_multi': notyetstrong,
      'try_catch_syntax_test_06_multi': notyetstrong,
      'try_catch_syntax_test_07_multi': notyetstrong,
      'try_catch_syntax_test_08_multi': notyetstrong,
      'try_catch_syntax_test_09_multi': notyetstrong,
      'try_catch_syntax_test_10_multi': notyetstrong,
      'try_catch_syntax_test_11_multi': notyetstrong,
      'try_catch_syntax_test_12_multi': notyetstrong,
      'try_catch_syntax_test_13_multi': notyetstrong,
      'try_catch_syntax_test_14_multi': notyetstrong,
      'try_catch_syntax_test_15_multi': notyetstrong,
      'try_catch_syntax_test_16_multi': notyetstrong,
      'try_catch_syntax_test_17_multi': notyetstrong,
      'try_catch_test_01_multi': notyetstrong,
      'try_catch_test_none_multi': notyetstrong,
      'type_argument_in_super_type_test': notyetstrong,
      'type_check_const_function_typedef2_test_00_multi': notyetstrong,
      'type_check_const_function_typedef2_test_none_multi': notyetstrong,
      'type_checks_in_factory_method_test': notyetstrong,
      'type_error_test': notyetstrong,
      'type_literal_prefix_call_test_00_multi': notyetstrong,
      'type_parameter_test_01_multi': notyetstrong,
      'type_parameter_test_02_multi': notyetstrong,
      'type_parameter_test_03_multi': notyetstrong,
      'type_parameter_test_04_multi': notyetstrong,
      'type_parameter_test_05_multi': notyetstrong,
      'type_parameter_test_06_multi': notyetstrong,
      'type_parameter_test_none_multi': notyetstrong,
      'type_promotion_assign_test_01_multi': notyetstrong,
      'type_promotion_assign_test_02_multi': notyetstrong,
      'type_promotion_assign_test_03_multi': notyetstrong,
      'type_promotion_assign_test_04_multi': notyetstrong,
      'type_promotion_closure_test_01_multi': notyetstrong,
      'type_promotion_closure_test_02_multi': notyetstrong,
      'type_promotion_closure_test_03_multi': notyetstrong,
      'type_promotion_closure_test_04_multi': notyetstrong,
      'type_promotion_closure_test_05_multi': notyetstrong,
      'type_promotion_closure_test_06_multi': notyetstrong,
      'type_promotion_closure_test_07_multi': notyetstrong,
      'type_promotion_closure_test_08_multi': notyetstrong,
      'type_promotion_closure_test_09_multi': notyetstrong,
      'type_promotion_closure_test_10_multi': notyetstrong,
      'type_promotion_closure_test_11_multi': notyetstrong,
      'type_promotion_closure_test_12_multi': notyetstrong,
      'type_promotion_closure_test_13_multi': notyetstrong,
      'type_promotion_closure_test_14_multi': notyetstrong,
      'type_promotion_closure_test_15_multi': notyetstrong,
      'type_promotion_closure_test_16_multi': notyetstrong,
      'type_promotion_closure_test_none_multi': notyetstrong,
      'type_promotion_functions_test_01_multi': notyetstrong,
      'type_promotion_functions_test_02_multi': notyetstrong,
      'type_promotion_functions_test_03_multi': notyetstrong,
      'type_promotion_functions_test_04_multi': notyetstrong,
      'type_promotion_functions_test_05_multi': notyetstrong,
      'type_promotion_functions_test_06_multi': notyetstrong,
      'type_promotion_functions_test_07_multi': notyetstrong,
      'type_promotion_functions_test_08_multi': notyetstrong,
      'type_promotion_functions_test_09_multi': notyetstrong,
      'type_promotion_functions_test_10_multi': notyetstrong,
      'type_promotion_functions_test_11_multi': notyetstrong,
      'type_promotion_functions_test_12_multi': notyetstrong,
      'type_promotion_functions_test_13_multi': notyetstrong,
      'type_promotion_functions_test_14_multi': notyetstrong,
      'type_promotion_functions_test_none_multi': notyetstrong,
      'type_promotion_local_test_01_multi': notyetstrong,
      'type_promotion_local_test_02_multi': notyetstrong,
      'type_promotion_local_test_03_multi': notyetstrong,
      'type_promotion_local_test_04_multi': notyetstrong,
      'type_promotion_local_test_05_multi': notyetstrong,
      'type_promotion_local_test_06_multi': notyetstrong,
      'type_promotion_local_test_07_multi': notyetstrong,
      'type_promotion_local_test_08_multi': notyetstrong,
      'type_promotion_local_test_09_multi': notyetstrong,
      'type_promotion_local_test_10_multi': notyetstrong,
      'type_promotion_local_test_11_multi': notyetstrong,
      'type_promotion_local_test_12_multi': notyetstrong,
      'type_promotion_local_test_13_multi': notyetstrong,
      'type_promotion_local_test_14_multi': notyetstrong,
      'type_promotion_local_test_15_multi': notyetstrong,
      'type_promotion_local_test_16_multi': notyetstrong,
      'type_promotion_local_test_17_multi': notyetstrong,
      'type_promotion_local_test_18_multi': notyetstrong,
      'type_promotion_local_test_19_multi': notyetstrong,
      'type_promotion_local_test_20_multi': notyetstrong,
      'type_promotion_local_test_21_multi': notyetstrong,
      'type_promotion_local_test_22_multi': notyetstrong,
      'type_promotion_local_test_23_multi': notyetstrong,
      'type_promotion_local_test_24_multi': notyetstrong,
      'type_promotion_local_test_25_multi': notyetstrong,
      'type_promotion_local_test_26_multi': notyetstrong,
      'type_promotion_local_test_27_multi': notyetstrong,
      'type_promotion_local_test_28_multi': notyetstrong,
      'type_promotion_local_test_29_multi': notyetstrong,
      'type_promotion_local_test_30_multi': notyetstrong,
      'type_promotion_local_test_31_multi': notyetstrong,
      'type_promotion_local_test_32_multi': notyetstrong,
      'type_promotion_local_test_33_multi': notyetstrong,
      'type_promotion_local_test_34_multi': notyetstrong,
      'type_promotion_local_test_35_multi': notyetstrong,
      'type_promotion_local_test_36_multi': notyetstrong,
      'type_promotion_local_test_37_multi': notyetstrong,
      'type_promotion_local_test_38_multi': notyetstrong,
      'type_promotion_local_test_39_multi': notyetstrong,
      'type_promotion_local_test_40_multi': notyetstrong,
      'type_promotion_local_test_41_multi': notyetstrong,
      'type_promotion_logical_and_test_01_multi': notyetstrong,
      'type_promotion_logical_and_test_02_multi': notyetstrong,
      'type_promotion_logical_and_test_03_multi': notyetstrong,
      'type_promotion_more_specific_test_02_multi': notyetstrong,
      'type_promotion_more_specific_test_04_multi': notyetstrong,
      'type_promotion_more_specific_test_06_multi': notyetstrong,
      'type_promotion_more_specific_test_07_multi': notyetstrong,
      'type_promotion_more_specific_test_09_multi': notyetstrong,
      'type_promotion_more_specific_test_10_multi': notyetstrong,
      'type_promotion_more_specific_test_11_multi': notyetstrong,
      'type_promotion_multiple_test_01_multi': notyetstrong,
      'type_promotion_multiple_test_02_multi': notyetstrong,
      'type_promotion_multiple_test_03_multi': notyetstrong,
      'type_promotion_multiple_test_04_multi': notyetstrong,
      'type_promotion_multiple_test_05_multi': notyetstrong,
      'type_promotion_multiple_test_06_multi': notyetstrong,
      'type_promotion_multiple_test_07_multi': notyetstrong,
      'type_promotion_multiple_test_08_multi': notyetstrong,
      'type_promotion_multiple_test_09_multi': notyetstrong,
      'type_promotion_multiple_test_10_multi': notyetstrong,
      'type_promotion_multiple_test_11_multi': notyetstrong,
      'type_promotion_multiple_test_12_multi': notyetstrong,
      'type_promotion_multiple_test_13_multi': notyetstrong,
      'type_promotion_multiple_test_14_multi': notyetstrong,
      'type_promotion_multiple_test_15_multi': notyetstrong,
      'type_promotion_multiple_test_16_multi': notyetstrong,
      'type_promotion_multiple_test_17_multi': notyetstrong,
      'type_promotion_multiple_test_18_multi': notyetstrong,
      'type_promotion_multiple_test_19_multi': notyetstrong,
      'type_promotion_multiple_test_20_multi': notyetstrong,
      'type_promotion_multiple_test_21_multi': notyetstrong,
      'type_promotion_multiple_test_22_multi': notyetstrong,
      'type_promotion_parameter_test_01_multi': notyetstrong,
      'type_promotion_parameter_test_02_multi': notyetstrong,
      'type_promotion_parameter_test_03_multi': notyetstrong,
      'type_promotion_parameter_test_04_multi': notyetstrong,
      'type_promotion_parameter_test_05_multi': notyetstrong,
      'type_promotion_parameter_test_06_multi': notyetstrong,
      'type_promotion_parameter_test_07_multi': notyetstrong,
      'type_promotion_parameter_test_08_multi': notyetstrong,
      'type_promotion_parameter_test_09_multi': notyetstrong,
      'type_promotion_parameter_test_10_multi': notyetstrong,
      'type_promotion_parameter_test_11_multi': notyetstrong,
      'type_promotion_parameter_test_12_multi': notyetstrong,
      'type_promotion_parameter_test_13_multi': notyetstrong,
      'type_promotion_parameter_test_14_multi': notyetstrong,
      'type_promotion_parameter_test_15_multi': notyetstrong,
      'type_promotion_parameter_test_16_multi': notyetstrong,
      'type_promotion_parameter_test_17_multi': notyetstrong,
      'type_promotion_parameter_test_18_multi': notyetstrong,
      'type_promotion_parameter_test_19_multi': notyetstrong,
      'type_promotion_parameter_test_20_multi': notyetstrong,
      'type_promotion_parameter_test_21_multi': notyetstrong,
      'type_promotion_parameter_test_22_multi': notyetstrong,
      'type_promotion_parameter_test_23_multi': notyetstrong,
      'type_promotion_parameter_test_24_multi': notyetstrong,
      'type_promotion_parameter_test_25_multi': notyetstrong,
      'type_promotion_parameter_test_26_multi': notyetstrong,
      'type_promotion_parameter_test_27_multi': notyetstrong,
      'type_promotion_parameter_test_28_multi': notyetstrong,
      'type_promotion_parameter_test_29_multi': notyetstrong,
      'type_promotion_parameter_test_30_multi': notyetstrong,
      'type_promotion_parameter_test_31_multi': notyetstrong,
      'type_promotion_parameter_test_32_multi': notyetstrong,
      'type_promotion_parameter_test_33_multi': notyetstrong,
      'type_promotion_parameter_test_34_multi': notyetstrong,
      'type_promotion_parameter_test_35_multi': notyetstrong,
      'type_promotion_parameter_test_36_multi': notyetstrong,
      'type_promotion_parameter_test_37_multi': notyetstrong,
      'type_promotion_parameter_test_38_multi': notyetstrong,
      'type_promotion_parameter_test_39_multi': notyetstrong,
      'type_promotion_parameter_test_40_multi': notyetstrong,
      'type_promotion_parameter_test_41_multi': notyetstrong,
      'type_promotion_parameter_test_42_multi': notyetstrong,
      'type_promotion_parameter_test_43_multi': notyetstrong,
      'type_promotion_parameter_test_44_multi': notyetstrong,
      'type_promotion_parameter_test_45_multi': notyetstrong,
      'type_promotion_parameter_test_46_multi': notyetstrong,
      'type_promotion_parameter_test_47_multi': notyetstrong,
      'type_promotion_parameter_test_48_multi': notyetstrong,
      'type_promotion_parameter_test_49_multi': notyetstrong,
      'type_promotion_parameter_test_50_multi': notyetstrong,
      'type_promotion_parameter_test_51_multi': notyetstrong,
      'type_promotion_parameter_test_52_multi': notyetstrong,
      'type_promotion_parameter_test_54_multi': notyetstrong,
      'type_promotion_parameter_test_55_multi': notyetstrong,
      'type_promotion_parameter_test_56_multi': notyetstrong,
      'type_variable_bounds2_test_00_multi': notyetstrong,
      'type_variable_bounds2_test_01_multi': notyetstrong,
      'type_variable_bounds2_test_02_multi': notyetstrong,
      'type_variable_bounds2_test_03_multi': notyetstrong,
      'type_variable_bounds2_test_04_multi': notyetstrong,
      'type_variable_bounds2_test_05_multi': notyetstrong,
      'type_variable_bounds2_test_06_multi': notyetstrong,
      'type_variable_bounds2_test_none_multi': notyetstrong,
      'type_variable_bounds3_test_00_multi': notyetstrong,
      'type_variable_bounds4_test_01_multi': notyetstrong,
      'type_variable_bounds4_test_none_multi': notyetstrong,
      'type_variable_bounds_test_00_multi': notyetstrong,
      'type_variable_bounds_test_01_multi': notyetstrong,
      'type_variable_bounds_test_02_multi': notyetstrong,
      'type_variable_bounds_test_03_multi': notyetstrong,
      'type_variable_bounds_test_04_multi': notyetstrong,
      'type_variable_bounds_test_05_multi': notyetstrong,
      'type_variable_bounds_test_06_multi': notyetstrong,
      'type_variable_bounds_test_07_multi': notyetstrong,
      'type_variable_bounds_test_08_multi': notyetstrong,
      'type_variable_bounds_test_09_multi': notyetstrong,
      'type_variable_bounds_test_10_multi': notyetstrong,
      'type_variable_bounds_test_none_multi': notyetstrong,
      'type_variable_conflict2_test_01_multi': notyetstrong,
      'type_variable_conflict2_test_02_multi': notyetstrong,
      'type_variable_conflict2_test_03_multi': notyetstrong,
      'type_variable_conflict2_test_04_multi': notyetstrong,
      'type_variable_conflict2_test_05_multi': notyetstrong,
      'type_variable_conflict2_test_06_multi': notyetstrong,
      'type_variable_conflict2_test_07_multi': notyetstrong,
      'type_variable_conflict2_test_08_multi': notyetstrong,
      'type_variable_conflict2_test_09_multi': notyetstrong,
      'type_variable_conflict2_test_10_multi': notyetstrong,
      'type_variable_conflict_test_01_multi': notyetstrong,
      'type_variable_conflict_test_02_multi': notyetstrong,
      'type_variable_conflict_test_03_multi': notyetstrong,
      'type_variable_conflict_test_04_multi': notyetstrong,
      'type_variable_conflict_test_05_multi': notyetstrong,
      'type_variable_conflict_test_06_multi': notyetstrong,
      'type_variable_function_type_test': notyetstrong,
      'type_variable_identifier_expression_test': notyetstrong,
      'type_variable_scope2_test': notyetstrong,
      'type_variable_scope3_test_00_multi': notyetstrong,
      'type_variable_scope_test_00_multi': notyetstrong,
      'type_variable_scope_test_01_multi': notyetstrong,
      'type_variable_scope_test_02_multi': notyetstrong,
      'type_variable_scope_test_03_multi': notyetstrong,
      'type_variable_scope_test_04_multi': notyetstrong,
      'type_variable_scope_test_05_multi': notyetstrong,
      'type_variable_scope_test_none_multi': notyetstrong,
      'typed_selector2_test': notyetstrong,
      'typevariable_substitution2_test_01_multi': notyetstrong,
      'typevariable_substitution2_test_02_multi': notyetstrong,
      'typevariable_substitution2_test_none_multi': notyetstrong,
      'unbalanced_brace_test_01_multi': notyetstrong,
      'unbalanced_brace_test_02_multi': notyetstrong,
      'unbound_getter_test': notyetstrong,
      'unresolved_default_constructor_test_01_multi': notyetstrong,
      'unsigned_right_shift_test_01_multi': notyetstrong,
      'unsigned_right_shift_test_02_multi': notyetstrong,
      'unsupported_operators_test_01_multi': notyetstrong,
      'unsupported_operators_test_02_multi': notyetstrong,
      'unsupported_operators_test_03_multi': notyetstrong,
      'unsupported_operators_test_04_multi': notyetstrong,
      'variable_declaration_metadata_test_01_multi': notyetstrong,
      'variable_declaration_metadata_test_02_multi': notyetstrong,
      'variable_declaration_metadata_test_03_multi': notyetstrong,
      'variable_declaration_metadata_test_04_multi': notyetstrong,
      'variable_declaration_metadata_test_05_multi': notyetstrong,
      'variable_declaration_metadata_test_06_multi': notyetstrong,
      'variable_declaration_metadata_test_07_multi': notyetstrong,
      'variable_declaration_metadata_test_08_multi': notyetstrong,
      'variable_declaration_metadata_test_09_multi': notyetstrong,
      'variable_declaration_metadata_test_10_multi': notyetstrong,
      'variable_declaration_metadata_test_11_multi': notyetstrong,
      'variable_declaration_metadata_test_12_multi': notyetstrong,
      'variable_declaration_metadata_test_13_multi': notyetstrong,
      'variable_declaration_metadata_test_14_multi': notyetstrong,
      'variable_declaration_metadata_test_15_multi': notyetstrong,
      'variable_declaration_metadata_test_16_multi': notyetstrong,
      'void_type_test': notyetstrong,
      'wrong_number_type_arguments_test_00_multi': notyetstrong,
      'wrong_number_type_arguments_test_01_multi': notyetstrong,
      'wrong_number_type_arguments_test_02_multi': notyetstrong,
    },

    'corelib': {
      'apply2_test': fail,
      'apply3_test': fail,
      'apply_test': fail,
      'big_integer_parsed_arith_vm_test': fail,
      'big_integer_parsed_div_rem_vm_test': fail,
      'big_integer_parsed_mul_div_vm_test': fail,
      'bit_twiddling_bigint_test': fail,
      'bool_from_environment_test': fail,
      'collection_length_test': skip_timeout,
      'compare_to2_test': fail,
      'const_list_literal_test': fail,
      'const_list_remove_range_test': fail,
      'const_list_set_range_test': fail,
      'double_parse_test_01_multi': fail,
      'error_stack_trace1_test': fail,
      'error_stack_trace2_test': fail,
      'file_resource_test': skip_fail, // crashes during import load.
      'from_environment_const_type_test_01_multi': skip_fail,  // constructor throws
      'from_environment_const_type_test_05_multi': skip_fail,  // constructor throws
      'from_environment_const_type_test_10_multi': skip_fail,  // constructor throws
      'from_environment_const_type_test_15_multi': skip_fail,  // constructor throws
      'from_environment_const_type_test_none_multi': skip_fail,  // constructor throws
      'from_environment_const_type_undefined_test_01_multi': skip_fail,  // constructor throws
      'from_environment_const_type_undefined_test_05_multi': skip_fail,  // constructor throws
      'from_environment_const_type_undefined_test_10_multi': skip_fail,  // constructor throws
      'from_environment_const_type_undefined_test_15_multi': skip_fail,  // constructor throws
      'from_environment_const_type_undefined_test_none_multi': skip_fail,  // constructor throws
      'hash_map2_test': skip_timeout,
      'hash_set_test_01_multi': fail,
      'hidden_library2_test_01_multi': fail,
      'indexed_list_access_test': fail,
      'int_from_environment2_test': fail,
      'int_from_environment_test': fail,
      'int_modulo_arith_test_bignum_multi': fail,
      'int_modulo_arith_test_modPow_multi': fail,
      'int_modulo_arith_test_none_multi': fail,
      'int_parse_radix_test_01_multi': fail, // JS implementations disagree on U+0085 being whitespace.
      'int_parse_radix_test_02_multi': ['fail', 'timeout', 'skip'], // No bigints.
      'int_parse_radix_test_none_multi': ['slow'],
      'integer_to_radix_string_test': fail,
      'integer_to_string_test_01_multi': fail,
      'iterable_generate_test': fail,
      'iterable_return_type_test_02_multi': fail,
      'json_map_test': fail,
      'list_fill_range_test': fail,
      'list_replace_range_test': fail,
      'list_set_all_test': fail,
      'list_to_string2_test': fail,
      'main_test': fail,
      'map_keys2_test': fail,
      'map_to_string_test': fail,
      'nan_infinity_test_01_multi': fail,
      'null_nosuchmethod_test': fail,
      'null_test': fail,
      'num_sign_test': fail,
      'queue_test': fail,
      'regress_r21715_test': fail,
      'throw_half_surrogate_pair_test_02_multi': fail,
      'stacktrace_current_test': fail,
      'string_from_environment2_test': fail,
      'string_from_environment_test': fail,
      'string_from_list_test': skip_timeout,
      'string_fromcharcodes_test': skip_timeout,
      'string_operations_with_null_test': fail,
      'symbol_reserved_word_test_06_multi': fail,
      'symbol_reserved_word_test_09_multi': fail,
      'symbol_reserved_word_test_12_multi': fail,
      'throw_half_surrogate_pair_test_01_multi': fail,
      // TODO(rnystrom): Times out because it tests a huge number of
      // combinations of URLs (4 * 5 * 5 * 8 * 6 * 6 * 4 = 115200).
      'uri_parse_test': skip_timeout,

      'big_integer_arith_vm_test_add_multi': notyetstrong,
      'big_integer_arith_vm_test_div_multi': notyetstrong,
      'big_integer_arith_vm_test_gcd_multi': notyetstrong,
      'big_integer_arith_vm_test_modInv_multi': notyetstrong,
      'big_integer_arith_vm_test_modPow_multi': notyetstrong,
      'big_integer_arith_vm_test_mod_multi': notyetstrong,
      'big_integer_arith_vm_test_mul_multi': notyetstrong,
      'big_integer_arith_vm_test_negate_multi': notyetstrong,
      'big_integer_arith_vm_test_none_multi': notyetstrong,
      'big_integer_arith_vm_test_overflow_multi': notyetstrong,
      'big_integer_arith_vm_test_shift_multi': notyetstrong,
      'big_integer_arith_vm_test_sub_multi': notyetstrong,
      'big_integer_arith_vm_test_trunDiv_multi': notyetstrong,
      'bool_from_environment2_test_01_multi': notyetstrong,
      'bool_from_environment2_test_02_multi': notyetstrong,
      'bool_from_environment2_test_03_multi': notyetstrong,
      'bool_from_environment2_test_04_multi': notyetstrong,
      'bool_from_environment2_test_05_multi': notyetstrong,
      'core_runtime_types_test': notyetstrong,
      'data_resource_test': notyetstrong,
      'duration2_test': notyetstrong,
      'error_stack_trace_test': notyetstrong,
      'from_environment_const_type_test_02_multi': notyetstrong,
      'from_environment_const_type_test_03_multi': notyetstrong,
      'from_environment_const_type_test_04_multi': notyetstrong,
      'from_environment_const_type_test_06_multi': notyetstrong,
      'from_environment_const_type_test_07_multi': notyetstrong,
      'from_environment_const_type_test_08_multi': notyetstrong,
      'from_environment_const_type_test_09_multi': notyetstrong,
      'from_environment_const_type_test_11_multi': notyetstrong,
      'from_environment_const_type_test_12_multi': notyetstrong,
      'from_environment_const_type_test_13_multi': notyetstrong,
      'from_environment_const_type_test_14_multi': notyetstrong,
      'from_environment_const_type_test_16_multi': notyetstrong,
      'from_environment_const_type_undefined_test_02_multi': notyetstrong,
      'from_environment_const_type_undefined_test_03_multi': notyetstrong,
      'from_environment_const_type_undefined_test_04_multi': notyetstrong,
      'from_environment_const_type_undefined_test_06_multi': notyetstrong,
      'from_environment_const_type_undefined_test_07_multi': notyetstrong,
      'from_environment_const_type_undefined_test_08_multi': notyetstrong,
      'from_environment_const_type_undefined_test_09_multi': notyetstrong,
      'from_environment_const_type_undefined_test_11_multi': notyetstrong,
      'from_environment_const_type_undefined_test_12_multi': notyetstrong,
      'from_environment_const_type_undefined_test_13_multi': notyetstrong,
      'from_environment_const_type_undefined_test_14_multi': notyetstrong,
      'from_environment_const_type_undefined_test_16_multi': notyetstrong,
      'growable_list_test': notyetstrong,
      'hash_set_type_check_test': notyetstrong,
      'http_resource_test': notyetstrong,
      'int_from_environment3_test_01_multi': notyetstrong,
      'int_from_environment3_test_02_multi': notyetstrong,
      'int_from_environment3_test_03_multi': notyetstrong,
      'int_from_environment3_test_04_multi': notyetstrong,
      'int_from_environment3_test_05_multi': notyetstrong,
      'iterable_contains2_test': notyetstrong,
      'iterable_element_at_test': notyetstrong,
      'iterable_fold_test': notyetstrong,
      'iterable_mapping_test': notyetstrong,
      'iterable_reduce_test': notyetstrong,
      'iterable_to_list_test': notyetstrong,
      'iterable_to_set_test': notyetstrong,
      'linked_hash_map_from_iterable_test': notyetstrong,
      'list_contains_argument_order_test': notyetstrong,
      'list_filled_type_argument_test': notyetstrong,
      'list_index_of2_test': notyetstrong,
      'list_insert_test': notyetstrong,
      'list_removeat_test': notyetstrong,
      'list_test_01_multi': notyetstrong,
      'list_test_none_multi': notyetstrong,
      'list_unmodifiable_test': notyetstrong,
      'map_test': notyetstrong,
      'num_clamp_test': notyetstrong,
      'package_resource_test': notyetstrong,
      'print_test_01_multi': notyetstrong,
      'print_test_none_multi': notyetstrong,
      'set_test': notyetstrong,
      'splay_tree_test': notyetstrong,
      'string_base_vm_test': notyetstrong,
      'string_from_environment3_test_01_multi': notyetstrong,
      'string_from_environment3_test_02_multi': notyetstrong,
      'string_from_environment3_test_03_multi': notyetstrong,
      'string_from_environment3_test_04_multi': notyetstrong,
      'string_from_environment3_test_05_multi': notyetstrong,
      'string_replace_test': notyetstrong,
      'string_test': notyetstrong,
      'symbol_operator_test_03_multi': notyetstrong,
      'symbol_operator_test_none_multi': notyetstrong,
      'symbol_reserved_word_test_04_multi': notyetstrong,
      'symbol_reserved_word_test_05_multi': notyetstrong,
      'symbol_reserved_word_test_07_multi': notyetstrong,
      'symbol_reserved_word_test_08_multi': notyetstrong,
      'symbol_reserved_word_test_10_multi': notyetstrong,
      'symbol_reserved_word_test_11_multi': notyetstrong,
      'symbol_test_01_multi': notyetstrong,
      'symbol_test_02_multi': notyetstrong,
      'symbol_test_03_multi': notyetstrong,
      'symbol_test_none_multi': notyetstrong,
      'uri_path_test': notyetstrong,
      'uri_query_test': notyetstrong,
    },

    'lib/convert': {
      // TODO(jmesserly): this could be a failure we didn't notice before
      // because we now call the right Dart double.toString, resulting in a
      // difference between -0.0 and 0?
      'chunked_conversion_json_encode1_test': fail,

      // TODO(rnystrom): A lot of the convert tests timeout. Some do pass if
      // you increase the time by a large amount, but it's pretty gratuitous.
      // I'm not sure why they are so slow. One guess is that they are spewing
      // a ton of warnings, that slow down the test.
      'chunked_conversion_utf84_test': skip_timeout,
      'chunked_conversion_utf88_test': skip_timeout,
      'chunked_conversion_utf8_test': skip_timeout,

      'chunked_conversion1_test': notyetstrong,

      'encoding_test': skip_timeout,

      // TODO(jmesserly): this is in an inconsistent state between our old and
      // newer SDKs.
      'html_escape_test': skip_fail,

      // TODO(jmesserly): seems to fail or pass based on SDK version?
      'html_escape_test': ['skip'],

      // TODO(rnystrom): If this test is enabled, karma gets confused and
      // disconnects randomly.
      'json_lib_test': skip_fail,

      'json_utf8_chunk_test': skip_timeout,

      // TODO(rnystrom): Strong mode cast failure.
      'line_splitter_test': fail,

      'streamed_conversion_json_encode1_test': skip_timeout,
      'streamed_conversion_json_utf8_decode_test': skip_timeout,
      'streamed_conversion_json_utf8_encode_test': skip_timeout,
      'streamed_conversion_utf8_decode_test': skip_timeout,
      'streamed_conversion_utf8_encode_test': skip_timeout,
      'utf85_test': skip_timeout,
    },

    // TODO(jacobr): enable more of the html tests in unittest once they have
    // more hope of passing. Triage tests that can never run in this test
    // runner and track them separately.
    'lib/html': {
      'async_spawnuri_test': ['unittest', 'skip', 'fail'],
      'async_test': ['unittest', 'skip', 'fail'],
      'audiobuffersourcenode_test': ['unittest', 'skip', 'fail'],
      'audiocontext_test': ['unittest', 'skip', 'fail'],
      'audioelement_test': ['unittest', 'skip', 'fail'],
      'b_element_test': ['unittest', 'skip', 'fail'],
      'blob_constructor_test': ['unittest', 'skip', 'fail'],
      'cache_test': ['unittest', 'skip', 'fail'],
      'callbacks_test': ['unittest', 'skip', 'fail'],
      'canvas_pixel_array_type_alias_test': ['unittest'],
      'canvasrenderingcontext2d_test': ['unittest'],
      'canvas_test': ['unittest'],
      'cdata_test': ['unittest', 'skip', 'fail'],
      'client_rect_test': ['unittest', 'skip', 'fail'],
      'cross_domain_iframe_test': ['unittest', 'skip', 'fail'],
      'cross_frame_test': ['unittest', 'skip', 'fail'],
      'crypto_test': ['unittest', 'skip', 'fail'],
      'css_rule_list_test': ['unittest', 'skip', 'fail'],
      'cssstyledeclaration_test': ['unittest', 'skip', 'fail'],
      'css_test': ['unittest', 'skip', 'fail'],
      'custom_element_method_clash_test': ['unittest', 'skip', 'fail'],
      'custom_element_name_clash_test': ['unittest', 'skip', 'fail'],
      'custom_elements_23127_test': ['unittest', 'skip', 'fail'],
      'custom_elements_test': ['unittest', 'skip', 'fail'],
      'custom_tags_test': ['unittest', 'skip', 'fail'],
      'dart_object_local_storage_test': ['unittest', 'skip', 'fail'],
      'datalistelement_test': ['unittest', 'skip', 'fail'],
      'documentfragment_test': ['unittest', 'skip', 'fail'],
      'document_test': ['unittest'],
      'dom_constructors_test': ['unittest', 'skip', 'fail'],
      'domparser_test': ['unittest', 'skip', 'fail'],
      'element_add_test': ['unittest', 'skip', 'fail'],
      'element_animate_test': ['unittest', 'skip', 'fail'],
      'element_classes_svg_test': ['unittest', 'skip', 'fail'],
      'element_classes_test': ['unittest', 'skip', 'fail'],
      'element_constructor_1_test': ['unittest', 'skip', 'fail'],
      'element_dimensions_test': ['unittest', 'skip', 'fail'],
      'element_offset_test': ['unittest', 'skip', 'fail'],
      'element_test': ['unittest', 'skip', 'fail'],
      'element_types_constructors1_test': ['unittest', 'skip', 'fail'],
      'element_types_constructors2_test': ['unittest', 'skip', 'fail'],
      'element_types_constructors3_test': ['unittest', 'skip', 'fail'],
      'element_types_constructors4_test': ['unittest', 'skip', 'fail'],
      'element_types_constructors5_test': ['unittest', 'skip', 'fail'],
      'element_types_constructors6_test': ['unittest', 'skip', 'fail'],
      'element_types_test': ['unittest', 'skip', 'fail'],
      'event_customevent_test': ['unittest', 'skip', 'fail'],
      'events_test': ['unittest', 'skip', 'fail'],
      'event_test': ['unittest', 'skip', 'fail'],
      'exceptions_test': ['unittest', 'skip', 'fail'],
      'fileapi_test': ['unittest', 'skip', 'fail'],
      'filereader_test': ['unittest', 'skip', 'fail'],
      'filteredelementlist_test': ['unittest', 'skip', 'fail'],
      'fontface_loaded_test': ['unittest', 'skip', 'fail'],
      'fontface_test': ['unittest', 'skip', 'fail'],
      'form_data_test': ['unittest', 'skip', 'fail'],
      'form_element_test': ['unittest', 'skip', 'fail'],
      'geolocation_test': ['unittest', 'skip', 'fail'],
      'hidden_dom_1_test': ['unittest', 'skip', 'fail'],
      'hidden_dom_2_test': ['unittest', 'skip', 'fail'],
      'history_test': ['unittest', 'skip', 'fail'],
      'htmlcollection_test': ['unittest', 'skip', 'fail'],
      'htmlelement_test': ['unittest', 'skip', 'fail'],
      'htmloptionscollection_test': ['unittest', 'skip', 'fail'],
      'indexeddb_1_test': ['unittest', 'skip', 'fail'],
      'indexeddb_2_test': ['unittest', 'skip', 'fail'],
      'indexeddb_3_test': ['unittest', 'skip', 'fail'],
      'indexeddb_4_test': ['unittest', 'skip', 'fail'],
      'indexeddb_5_test': ['unittest', 'skip', 'fail'],
      'input_element_test': ['unittest', 'skip', 'fail'],
      'instance_of_test': ['unittest', 'skip', 'fail'],
      'interactive_test': ['unittest', 'skip', 'fail'],
      'isolates_test': ['unittest', 'skip', 'fail'],
      'js_function_getter_test': 'unittest',
      'js_function_getter_trust_types_test': 'unittest',
      'js_interop_1_test': 'unittest',
      'js_test': 'unittest',
      'js_typed_interop_anonymous2_exp_test': 'unittest',
      'js_typed_interop_anonymous2_test': 'unittest',
      'js_typed_interop_anonymous_exp_test': 'unittest',
      'js_typed_interop_anonymous_test': 'unittest',
      'js_typed_interop_anonymous_unreachable_exp_test': 'unittest',
      'js_typed_interop_anonymous_unreachable_test': 'unittest',
      'js_typed_interop_default_arg_test': 'unittest',
      'js_typed_interop_side_cast_exp_test': 'unittest',
      'js_typed_interop_side_cast_test': 'unittest',
      'js_typed_interop_test': ['unittest', 'skip', 'fail'],
      'keyboard_event_test': ['unittest', 'skip', 'fail'],
      'localstorage_test': ['unittest', 'skip', 'fail'],
      'location_test': ['unittest', 'skip', 'fail'],
      'mediasource_test': ['unittest', 'skip', 'fail'],
      'media_stream_test': ['unittest', 'skip', 'fail'],
      'messageevent_test': ['unittest', 'skip', 'fail'],
      'mirrors_js_typed_interop_test': ['unittest', 'skip', 'fail'],
      'mouse_event_test': ['unittest', 'skip', 'fail'],
      'mutationobserver_test': ['unittest', 'skip', 'fail'],
      'native_gc_test': ['unittest', 'skip', 'fail'],
      'navigator_test': ['unittest', 'skip', 'fail'],
      'node_test': ['unittest', 'skip', 'fail'],
      'node_validator_important_if_you_suppress_make_the_bug_critical_test': ['unittest', 'skip', 'fail'],
      'non_instantiated_is_test': ['unittest', 'skip', 'fail'],
      'notification_test': ['unittest', 'skip', 'fail'],
      'performance_api_test': ['unittest', 'skip', 'fail'],
      'postmessage_structured_test': ['unittest', 'skip', 'fail'],
      'private_extension_member_test': ['unittest', 'skip', 'fail'],
      'queryall_test': ['unittest', 'skip', 'fail'],
      'query_test': ['unittest', 'skip', 'fail'],
      'range_test': ['unittest', 'skip', 'fail'],
      'request_animation_frame_test': ['unittest', 'skip', 'fail'],
      'resource_http_test': ['unittest', 'skip', 'fail'],
      'rtc_test': ['unittest', 'skip', 'fail'],
      'selectelement_test': ['unittest', 'skip', 'fail'],
      'serialized_script_value_test': ['unittest', 'skip', 'fail'],
      'shadow_dom_test': ['unittest', 'skip', 'fail'],
      'shadowroot_test': ['unittest', 'skip', 'fail'],
      'speechrecognition_test': ['unittest', 'skip', 'fail'],
      'storage_test': ['unittest', 'skip', 'fail'],
      'streams_test': ['unittest', 'skip', 'fail'],
      'svgelement_test': ['unittest', 'skip', 'fail'],
      'svg_test': ['unittest', 'skip', 'fail'],
      'table_test': ['unittest', 'skip', 'fail'],
      'text_event_test': ['unittest', 'skip', 'fail'],
      'touchevent_test': ['unittest', 'skip', 'fail'],
      'track_element_constructor_test': ['unittest', 'skip', 'fail'],
      'transferables_test': ['unittest', 'skip', 'fail'],
      'transition_event_test': ['unittest', 'skip', 'fail'],
      'trusted_html_tree_sanitizer_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_1_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_2_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_3_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_4_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_5_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_arraybuffer_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_dataview_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_range_checks_test': ['unittest', 'skip', 'fail'],
      'typed_arrays_simd_test': ['unittest', 'skip', 'fail'],
      'typing_test': ['unittest', 'skip', 'fail'],
      'unknownelement_test': ['unittest', 'skip', 'fail'],
      'uri_test': ['unittest', 'skip', 'fail'],
      'url_test': ['unittest', 'skip', 'fail'],
      'webgl_1_test': ['unittest', 'skip', 'fail'],
      'websocket_test': ['unittest', 'skip', 'fail'],
      'websql_test': ['unittest', 'skip', 'fail'],
      'wheelevent_test': ['unittest', 'skip', 'fail'],
      'window_eq_test': ['unittest', 'skip', 'fail'],
      'window_mangling_test': ['unittest', 'skip', 'fail'],
      'window_nosuchmethod_test': ['unittest', 'skip', 'fail'],
      'window_test': ['unittest', 'skip', 'fail'],
      'worker_api_test': ['unittest', 'skip', 'fail'],
      'worker_test': ['unittest', 'skip', 'fail'],
      'wrapping_collections_test': ['unittest', 'skip', 'fail'],
      'xhr_cross_origin_test': ['unittest', 'skip', 'fail'],
      'xhr_test': ['unittest', 'skip', 'fail'],
      'xsltprocessor_test': ['unittest', 'skip', 'fail'],

      'js_typed_interop_default_arg_test_none_multi': ['unittest', 'skip', 'fail'],
      'js_typed_interop_default_arg_test_explicit_argument_multi': ['unittest', 'skip', 'fail'],
      'js_typed_interop_default_arg_test_default_value_multi': ['unittest', 'skip', 'fail']
    },

    'lib/math': {
      // TODO(het): triage
      'double_pow_test': skip_fail,
      'low_test': skip_fail,
      'math_test': skip_fail,
      'math2_test': skip_fail,
      'min_max_test': notyetstrong,
      'random_big_test': skip_fail,
      'point_test': ['unittest', 'skip', 'fail'],
      'rectangle_test': ['unittest', 'skip', 'fail'],
    },

    'lib/typed_data': {
      // No bigint or int64 support
      'float32x4_test': notyetstrong,
      'float64x2_functional_test': notyetstrong,
      'int32x4_bigint_test': skip_fail,
      'int32x4_test': notyetstrong,
      'int64_list_load_store_test': skip_fail,
      'typed_data_hierarchy_int64_test': skip_fail,
      'typed_data_list_test': fail,
    },
  };

  function countMatches(text, regex) {
    let matches = text.match(regex);
    return matches ? matches.length : 0;
  }

  let unittest_tests = [];

  let languageTestPattern = new RegExp('(.*)/([^/]*_test[^/]*)');
  html_config.useHtmlConfiguration();
  // We need to let Dart unittest control when tests are run not mocha.
  // mocha.allowUncaught(true);
  let dartUnittestsLeft = 0;
  for (let testFile of dart_library.libraries()) {
    let match = languageTestPattern.exec(testFile);
    if (match != null) {
      let status_group = match[1]
      let name = match[2];
      let module = match[0];

      let status = all_status[status_group];
      if (status == null) throw "No status for '" + status_group + "'";

      let expectation = status[name];
      if (expectation == null) expectation = [];
      if (typeof expectation == 'string') expectation = [expectation];
      function has(tag) {
        return expectation.indexOf(tag) >= 0;
      }

      if (has('helper')) {
        // These are not top-level tests.  They are used by other tests.
        continue;
      }

      if (has('skip')) {
        let why = 'for unknown reason';
        if (has('timeout')) why = 'known timeout';
        if (has('fail')) why = 'known failure';
        console.debug('Skipping ' + why + ': ' + name);
        continue;
      }

      // A few tests are special because they use package:unittest.
      // We run them below.
      if (has('unittest')) {
        unittest_tests.push(() => {
          console.log('Running unittest test ' + testFile);
          dart_library.import(module)[name].main();
        });
        continue;
      }

      function protect(f) {  // Returns the exception, or `null`.
        try {
          f();
          return null;
        } catch (e) {
          return e;
        }
      }

      test(name, function(done) { // 'function' to allow `this.timeout`.
        async_helper.asyncTestInitialize(done);
        console.debug('Running test:  ' + name);

        let mainLibrary = dart_library.import(module)[name];
        let negative = /negative_test/.test(name);
        if (has('slow')) this.timeout(10000);
        if (has('notyetstrong')) {
          let e = protect(mainLibrary.main);
          if (e == null) {
              throw new Error(
                  "test marked as 'notyetstrong' due to " +
                  "strong mode errors, but passed");
          } else if (!(e instanceof Error) ||
                     !e.message.startsWith("DDC Compilation Error:")) {
              throw new Error(
                  "test marked as 'notyetstrong' due to " +
                  "strong mode errors, but ran and threw:\n" + e);
          }
        } else if (has('fail')) {
          let e = protect(mainLibrary.main);
          if (negative) {
            if (e != null) {
              throw new Error(
                  "negative test marked as 'fail' " +
                  "but passed by throwing:\n" + e);
            }
          } else {
            if (e == null) {
              throw new Error("test marked as 'fail' but passed");
            }
          }
        } else {
          if (negative) {
            assert.throws(mainLibrary.main);
          } else {
            mainLibrary.main();
          }
        }

        if (!async_helper.asyncTestStarted) done();
      });
    }
  }

  let mochaOnError;
  // We run these tests in a mocha test wrapper to avoid the confusing failure
  // case of dart unittests being interleaved with mocha tests.
  // In practice we are really just suppressing all mocha test behavior while
  // Dart unittests run and then re-enabling it when the dart tests complete.
  test('run all dart unittests', function(done) { // 'function' to allow `this.timeout`
    this.timeout(100000000);
    this.enableTimeouts(false);
    // Suppress mocha on-error handling because it will mess up unittests.
    mochaOnError = window.onerror;
    window.onerror = function(err, url, line) {
      console.error(err, url, line);
    };
    window.addEventListener('message', (event) => {
      if (event.data == 'unittest-suite-done') {
        window.console.log("Done running unittests");
        let output = document.body.textContent;
        // Restore the Mocha onerror handler in case future tests need to run.
        window.onerror = mochaOnError;
        this.enableTimeouts(true);

        let numErrors = countMatches(output, /\d\s+ERROR/g);
        let numFails = countMatches(output, /\d\s+FAIL/g);
        if (numErrors != num_expected_unittest_errors ||
            numFails != num_expected_unittest_fails) {
          output = "Expected " + num_expected_unittest_fails +
              " fail and " + num_expected_unittest_errors +
              " error unittests, got " + numFails + " fail and " +
              numErrors + "error tests.\n" + output;
          console.error(output);
          done(new Error(output));
        } else {
          console.log(output);
          done();
        }
      }
    });

    for (let action of unittest_tests) {
      try {
        action();
      } catch (e) {
        console.error("Caught error tying to setup test:", e);
      }
    }
  });
})();
